# -coding=latin1-

from warnings import warnpy3k
warnpy3k("In 3.x, the macerrors module is removed.", stacklevel=2)

svTempDisable   =   -32768  #svTempDisable
svDisabled  =   -32640  #Reserve range -32640 to -32768 for Apple temp disables.
fontNotOutlineErr   =   -32615  #bitmap font passed to routine that does outlines only
kURL68kNotSupportedError    =   -30788  #kURL68kNotSupportedError
kURLAccessNotAvailableError =   -30787  #kURLAccessNotAvailableError
kURLInvalidConfigurationError   =   -30786  #kURLInvalidConfigurationError
kURLExtensionFailureError   =   -30785  #kURLExtensionFailureError
kURLFileEmptyError  =   -30783  #kURLFileEmptyError
kURLInvalidCallError    =   -30781  #kURLInvalidCallError
kURLUnsettablePropertyError =   -30780  #kURLUnsettablePropertyError
kURLPropertyBufferTooSmallError =   -30779  #kURLPropertyBufferTooSmallError
kURLUnknownPropertyError    =   -30778  #kURLUnknownPropertyError
kURLPropertyNotYetKnownError    =   -30777  #kURLPropertyNotYetKnownError
kURLAuthenticationError =   -30776  #kURLAuthenticationError
kURLServerBusyError =   -30775  #kURLServerBusyError
kURLUnsupportedSchemeError  =   -30774  #kURLUnsupportedSchemeError
kURLInvalidURLError =   -30773  #kURLInvalidURLError
kURLDestinationExistsError  =   -30772  #kURLDestinationExistsError
kURLProgressAlreadyDisplayedError   =   -30771  #kURLProgressAlreadyDisplayedError
kURLInvalidURLReferenceError    =   -30770  #kURLInvalidURLReferenceError
controlHandleInvalidErr =   -30599  #controlHandleInvalidErr
controlInvalidDataVersionErr    =   -30597  #controlInvalidDataVersionErr
errItemNotControl   =   -30596  #errItemNotControl
errCantEmbedRoot    =   -30595  #errCantEmbedRoot
errCantEmbedIntoSelf    =   -30594  #errCantEmbedIntoSelf
errWindowRegionCodeInvalid  =   -30593  #errWindowRegionCodeInvalid
errControlHiddenOrDisabled  =   -30592  #errControlHiddenOrDisabled
errDataSizeMismatch =   -30591  #errDataSizeMismatch
errControlIsNotEmbedder =   -30590  #errControlIsNotEmbedder
errControlsAlreadyExist =   -30589  #errControlsAlreadyExist
errInvalidPartCode  =   -30588  #errInvalidPartCode
errRootAlreadyExists    =   -30587  #errRootAlreadyExists
errNoRootControl    =   -30586  #errNoRootControl
errCouldntSetFocus  =   -30585  #errCouldntSetFocus
errUnknownControl   =   -30584  #errUnknownControl
errWindowDoesntSupportFocus =   -30583  #errWindowDoesntSupportFocus
errControlDoesntSupportFocus    =   -30582  #errControlDoesntSupportFocus
errDataNotSupported =   -30581  #errDataNotSupported
errMessageNotSupported  =   -30580  #errMessageNotSupported
themeMonitorDepthNotSupportedErr    =   -30567  #theme not supported at monitor depth
themeScriptFontNotFoundErr  =   -30566  #theme font requested for uninstalled script system
themeBadCursorIndexErr  =   -30565  #themeBadCursorIndexErr
themeHasNoAccentsErr    =   -30564  #themeHasNoAccentsErr
themeBadTextColorErr    =   -30563  #themeBadTextColorErr
themeProcessNotRegisteredErr    =   -30562  #themeProcessNotRegisteredErr
themeProcessRegisteredErr   =   -30561  #themeProcessRegisteredErr
themeInvalidBrushErr    =   -30560  #pattern index invalid
qtvrUninitialized   =   -30555  #qtvrUninitialized
qtvrLibraryLoadErr  =   -30554  #qtvrLibraryLoadErr
streamingNodeNotReadyErr    =   -30553  #streamingNodeNotReadyErr
noMemoryNodeFailedInitialize    =   -30552  #noMemoryNodeFailedInitialize
invalidHotSpotIDErr =   -30551  #invalidHotSpotIDErr
invalidNodeFormatErr    =   -30550  #invalidNodeFormatErr
limitReachedErr =   -30549  #limitReachedErr
settingNotSupportedByNodeErr    =   -30548  #settingNotSupportedByNodeErr
propertyNotSupportedByNodeErr   =   -30547  #propertyNotSupportedByNodeErr
timeNotInViewErr    =   -30546  #timeNotInViewErr
invalidViewStateErr =   -30545  #invalidViewStateErr
invalidNodeIDErr    =   -30544  #invalidNodeIDErr
selectorNotSupportedByNodeErr   =   -30543  #selectorNotSupportedByNodeErr
callNotSupportedByNodeErr   =   -30542  #callNotSupportedByNodeErr
constraintReachedErr    =   -30541  #constraintReachedErr
notAQTVRMovieErr    =   -30540  #notAQTVRMovieErr
kFBCnoSuchHit   =   -30532  #kFBCnoSuchHit
kFBCbadSearchSession    =   -30531  #kFBCbadSearchSession
kFBCindexDiskIOFailed   =   -30530  #kFBCindexDiskIOFailed
kFBCsummarizationCanceled   =   -30529  #kFBCsummarizationCanceled
kFBCbadIndexFileVersion =   -30528  #kFBCbadIndexFileVersion
kFBCanalysisNotAvailable    =   -30527  #kFBCanalysisNotAvailable
kFBCillegalSessionChange    =   -30526  #tried to add/remove vols to a session
kFBCsomeFilesNotIndexed =   -30525  #kFBCsomeFilesNotIndexed
kFBCsearchFailed    =   -30524  #kFBCsearchFailed
kFBCindexNotAvailable   =   -30523  #kFBCindexNotAvailable
kFBCindexFileDestroyed  =   -30522  #kFBCindexFileDestroyed
kFBCaccessCanceled  =   -30521  #kFBCaccessCanceled
kFBCindexingCanceled    =   -30520  #kFBCindexingCanceled
kFBCnoSearchSession =   -30519  #kFBCnoSearchSession
kFBCindexNotFound   =   -30518  #kFBCindexNotFound
kFBCflushFailed =   -30517  #kFBCflushFailed
kFBCaddDocFailed    =   -30516  #kFBCaddDocFailed
kFBCaccessorStoreFailed =   -30515  #kFBCaccessorStoreFailed
kFBCindexCreationFailed =   -30514  #couldn't create index
kFBCmergingFailed   =   -30513  #couldn't merge index files
kFBCtokenizationFailed  =   -30512  #couldn't read from document or query
kFBCmoveFailed  =   -30511  #V-Twin exception caught
kFBCdeletionFailed  =   -30510  #V-Twin exception caught
kFBCcommitFailed    =   -30509  #V-Twin exception caught
kFBCindexingFailed  =   -30508  #V-Twin exception caught
kFBCvalidationFailed    =   -30507  #V-Twin exception caught
kFBCcompactionFailed    =   -30506  #V-Twin exception caught
kFBCbadIndexFile    =   -30505  #bad FSSpec, or bad data in file
kFBCfileNotIndexed  =   -30504  #kFBCfileNotIndexed
kFBCbadParam    =   -30503  #kFBCbadParam
kFBCallocFailed =   -30502  #probably low memory
kFBCnoIndexesFound  =   -30501  #kFBCnoIndexesFound
kFBCvTwinExceptionErr   =   -30500  #no telling what it was
kDSpStereoContextErr    =   -30450  #kDSpStereoContextErr
kDSpInternalErr =   -30449  #kDSpInternalErr
kDSpConfirmSwitchWarning    =   -30448  #kDSpConfirmSwitchWarning
kDSpFrameRateNotReadyErr    =   -30447  #kDSpFrameRateNotReadyErr
kDSpContextNotFoundErr  =   -30446  #kDSpContextNotFoundErr
kDSpContextNotReservedErr   =   -30445  #kDSpContextNotReservedErr
kDSpContextAlreadyReservedErr   =   -30444  #kDSpContextAlreadyReservedErr
kDSpInvalidAttributesErr    =   -30443  #kDSpInvalidAttributesErr
kDSpInvalidContextErr   =   -30442  #kDSpInvalidContextErr
kDSpSystemSWTooOldErr   =   -30441  #kDSpSystemSWTooOldErr
kDSpNotInitializedErr   =   -30440  #kDSpNotInitializedErr
kISpListBusyErr =   -30429  #kISpListBusyErr
kISpDeviceActiveErr =   -30428  #kISpDeviceActiveErr
kISpSystemActiveErr =   -30427  #kISpSystemActiveErr
kISpDeviceInactiveErr   =   -30426  #kISpDeviceInactiveErr
kISpSystemInactiveErr   =   -30425  #kISpSystemInactiveErr
kISpElementNotInListErr =   -30424  #kISpElementNotInListErr
kISpElementInListErr    =   -30423  #kISpElementInListErr
kISpBufferToSmallErr    =   -30422  #kISpBufferToSmallErr
kISpSystemListErr   =   -30421  #kISpSystemListErr
kISpInternalErr =   -30420  #kISpInternalErr
kNSpJoinFailedErr   =   -30399  #kNSpJoinFailedErr
kNSpCantBlockErr    =   -30398  #kNSpCantBlockErr
kNSpMessageTooBigErr    =   -30397  #kNSpMessageTooBigErr
kNSpSendFailedErr   =   -30396  #kNSpSendFailedErr
kNSpConnectFailedErr    =   -30395  #kNSpConnectFailedErr
kNSpGameTerminatedErr   =   -30394  #kNSpGameTerminatedErr
kNSpTimeoutErr  =   -30393  #kNSpTimeoutErr
kNSpInvalidProtocolListErr  =   -30392  #kNSpInvalidProtocolListErr
kNSpInvalidProtocolRefErr   =   -30391  #kNSpInvalidProtocolRefErr
kNSpInvalidDefinitionErr    =   -30390  #kNSpInvalidDefinitionErr
kNSpAddPlayerFailedErr  =   -30389  #kNSpAddPlayerFailedErr
kNSpCreateGroupFailedErr    =   -30388  #kNSpCreateGroupFailedErr
kNSpNoHostVolunteersErr =   -30387  #kNSpNoHostVolunteersErr
kNSpNoGroupsErr =   -30386  #kNSpNoGroupsErr
kNSpNoPlayersErr    =   -30385  #kNSpNoPlayersErr
kNSpInvalidGroupIDErr   =   -30384  #kNSpInvalidGroupIDErr
kNSpInvalidPlayerIDErr  =   -30383  #kNSpInvalidPlayerIDErr
kNSpNameRequiredErr =   -30382  #kNSpNameRequiredErr
kNSpFeatureNotImplementedErr    =   -30381  #kNSpFeatureNotImplementedErr
kNSpAddressInUseErr =   -30380  #kNSpAddressInUseErr
kNSpRemovePlayerFailedErr   =   -30379  #kNSpRemovePlayerFailedErr
kNSpFreeQExhaustedErr   =   -30378  #kNSpFreeQExhaustedErr
kNSpInvalidAddressErr   =   -30377  #kNSpInvalidAddressErr
kNSpNotAdvertisingErr   =   -30376  #kNSpNotAdvertisingErr
kNSpAlreadyAdvertisingErr   =   -30374  #kNSpAlreadyAdvertisingErr
kNSpMemAllocationErr    =   -30373  #kNSpMemAllocationErr
kNSpOTVersionTooOldErr  =   -30371  #kNSpOTVersionTooOldErr
kNSpOTNotPresentErr =   -30370  #kNSpOTNotPresentErr
kNSpInvalidParameterErr =   -30369  #kNSpInvalidParameterErr
kNSpInvalidGameRefErr   =   -30367  #kNSpInvalidGameRefErr
kNSpProtocolNotAvailableErr =   -30366  #kNSpProtocolNotAvailableErr
kNSpHostFailedErr   =   -30365  #kNSpHostFailedErr
kNSpPipeFullErr =   -30364  #kNSpPipeFullErr
kNSpTopologyNotSupportedErr =   -30362  #kNSpTopologyNotSupportedErr
kNSpAlreadyInitializedErr   =   -30361  #kNSpAlreadyInitializedErr
kNSpInitializationFailedErr =   -30360  #kNSpInitializationFailedErr
kSSpScaleToZeroErr  =   -30344  #kSSpScaleToZeroErr
kSSpParallelUpVectorErr =   -30343  #kSSpParallelUpVectorErr
kSSpCantInstallErr  =   -30342  #kSSpCantInstallErr
kSSpVersionErr  =   -30341  #kSSpVersionErr
kSSpInternalErr =   -30340  #kSSpInternalErr
kALMInternalErr =   -30049  #kALMInternalErr
kALMGroupNotFoundErr    =   -30048  #kALMGroupNotFoundErr
kALMNoSuchModuleErr =   -30047  #kALMNoSuchModuleErr
kALMModuleCommunicationErr  =   -30046  #kALMModuleCommunicationErr
kALMDuplicateModuleErr  =   -30045  #kALMDuplicateModuleErr
kALMInstallationErr =   -30044  #kALMInstallationErr
kALMDeferSwitchErr  =   -30043  #kALMDeferSwitchErr
kALMRebootFlagsLevelErr =   -30042  #kALMRebootFlagsLevelErr
kLocalesDefaultDisplayStatus    =   -30029  #Requested display locale unavailable, used default
kLocalesTableFormatErr  =   -30002  #kLocalesTableFormatErr
kLocalesBufferTooSmallErr   =   -30001  #kLocalesBufferTooSmallErr
kFNSNameNotFoundErr =   -29589  #The name with the requested paramters was not found
kFNSBadFlattenedSizeErr =   -29587  #flattened size didn't match input or was too small
kFNSInsufficientDataErr =   -29586  #insufficient data for the operation
kFNSMismatchErr =   -29585  #reference didn't match or wasn't found in profile
kFNSDuplicateReferenceErr   =   -29584  #the ref. being added is already in the profile
kFNSBadProfileVersionErr    =   -29583  #profile version is out of known range
kFNSInvalidProfileErr   =   -29582  #profile is NULL or otherwise bad
kFNSBadReferenceVersionErr  =   -29581  #ref. version is out of known range
kFNSInvalidReferenceErr =   -29580  #ref. was NULL or otherwise bad
kCollateInvalidCollationRef =   -29507  #kCollateInvalidCollationRef
kCollateBufferTooSmall  =   -29506  #kCollateBufferTooSmall
kCollateInvalidChar =   -29505  #kCollateInvalidChar
kCollatePatternNotFoundErr  =   -29504  #kCollatePatternNotFoundErr
kCollateUnicodeConvertFailedErr =   -29503  #kCollateUnicodeConvertFailedErr
kCollateMissingUnicodeTableErr  =   -29502  #kCollateMissingUnicodeTableErr
kCollateInvalidOptions  =   -29501  #kCollateInvalidOptions
kCollateAttributesNotFoundErr   =   -29500  #kCollateAttributesNotFoundErr
kMPInvalidIDErr =   -29299  #kMPInvalidIDErr
kMPInsufficientResourcesErr =   -29298  #kMPInsufficientResourcesErr
kMPTaskAbortedErr   =   -29297  #kMPTaskAbortedErr
kMPTimeoutErr   =   -29296  #kMPTimeoutErr
kMPDeletedErr   =   -29295  #kMPDeletedErr
kMPBlueBlockingErr  =   -29293  #kMPBlueBlockingErr
kMPTaskStoppedErr   =   -29292  #A convention used with MPThrowException.
kMPTaskBlockedErr   =   -29291  #kMPTaskBlockedErr
kMPTaskCreatedErr   =   -29290  #kMPTaskCreatedErr
kMPProcessTerminatedErr =   -29289  #kMPProcessTerminatedErr
kMPProcessCreatedErr    =   -29288  #kMPProcessCreatedErr
kMPPrivilegedErr    =   -29276  #kMPPrivilegedErr
kMPIterationEndErr  =   -29275  #kMPIterationEndErr
kUCTextBreakLocatorMissingType  =   -25341  #Unicode text break error
kUCOutputBufferTooSmall =   -25340  #Output buffer too small for Unicode string result
errKCCreateChainFailed  =   -25318  #errKCCreateChainFailed
errKCDataNotModifiable  =   -25317  #errKCDataNotModifiable
errKCDataNotAvailable   =   -25316  #errKCDataNotAvailable
errKCInteractionRequired    =   -25315  #errKCInteractionRequired
errKCNoPolicyModule =   -25314  #errKCNoPolicyModule
errKCNoCertificateModule    =   -25313  #errKCNoCertificateModule
errKCNoStorageModule    =   -25312  #errKCNoStorageModule
errKCKeySizeNotAllowed  =   -25311  #errKCKeySizeNotAllowed
errKCWrongKCVersion =   -25310  #errKCWrongKCVersion
errKCReadOnlyAttr   =   -25309  #errKCReadOnlyAttr
errKCInteractionNotAllowed  =   -25308  #errKCInteractionNotAllowed
errKCNoDefaultKeychain  =   -25307  #errKCNoDefaultKeychain
errKCNoSuchClass    =   -25306  #errKCNoSuchClass
errKCInvalidSearchRef   =   -25305  #errKCInvalidSearchRef
errKCInvalidItemRef =   -25304  #errKCInvalidItemRef
errKCNoSuchAttr =   -25303  #errKCNoSuchAttr
errKCDataTooLarge   =   -25302  #errKCDataTooLarge
errKCBufferTooSmall =   -25301  #errKCBufferTooSmall
errKCItemNotFound   =   -25300  #errKCItemNotFound
errKCDuplicateItem  =   -25299  #errKCDuplicateItem
errKCInvalidCallback    =   -25298  #errKCInvalidCallback
errKCDuplicateCallback  =   -25297  #errKCDuplicateCallback
errKCDuplicateKeychain  =   -25296  #errKCDuplicateKeychain
errKCInvalidKeychain    =   -25295  #errKCInvalidKeychain
errKCNoSuchKeychain =   -25294  #errKCNoSuchKeychain
errKCAuthFailed =   -25293  #errKCAuthFailed
errKCReadOnly   =   -25292  #errKCReadOnly
errKCNotAvailable   =   -25291  #errKCNotAvailable
printerStatusOpCodeNotSupportedErr  =   -25280  #printerStatusOpCodeNotSupportedErr
kTXNOutsideOfFrameErr   =   -22018  #kTXNOutsideOfFrameErr
kTXNOutsideOfLineErr    =   -22017  #kTXNOutsideOfLineErr
kTXNATSUIIsNotInstalledErr  =   -22016  #kTXNATSUIIsNotInstalledErr
kTXNDataTypeNotAllowedErr   =   -22015  #kTXNDataTypeNotAllowedErr
kTXNCopyNotAllowedInEchoModeErr =   -22014  #kTXNCopyNotAllowedInEchoModeErr
kTXNCannotTurnTSMOffWhenUsingUnicodeErr =   -22013  #kTXNCannotTurnTSMOffWhenUsingUnicodeErr
kTXNAlreadyInitializedErr   =   -22012  #kTXNAlreadyInitializedErr
kTXNInvalidRunIndex =   -22011  #kTXNInvalidRunIndex
kTXNSomeOrAllTagsInvalidForRunErr   =   -22010  #kTXNSomeOrAllTagsInvalidForRunErr
kTXNAttributeTagInvalidForRunErr    =   -22009  #dataValue is set to this per invalid tag
kTXNNoMatchErr  =   -22008  #kTXNNoMatchErr
kTXNRunIndexOutofBoundsErr  =   -22007  #kTXNRunIndexOutofBoundsErr
kTXNCannotSetAutoIndentErr  =   -22006  #kTXNCannotSetAutoIndentErr
kTXNBadDefaultFileTypeWarning   =   -22005  #kTXNBadDefaultFileTypeWarning
kTXNUserCanceledOperationErr    =   -22004  #kTXNUserCanceledOperationErr
kTXNIllegalToCrossDataBoundariesErr =   -22003  #kTXNIllegalToCrossDataBoundariesErr
kTXNInvalidFrameIDErr   =   -22002  #kTXNInvalidFrameIDErr
kTXNCannotAddFrameErr   =   -22001  #kTXNCannotAddFrameErr
kTXNEndIterationErr =   -22000  #kTXNEndIterationErr
invalidIndexErr =   -20002  #The recordIndex parameter is not valid.
recordDataTooBigErr =   -20001  #The record data is bigger than buffer size (1024 bytes).
unknownInsertModeErr    =   -20000  #There is no such an insert mode.
kModemScriptMissing =   -14002  #kModemScriptMissing
kModemPreferencesMissing    =   -14001  #kModemPreferencesMissing
kModemOutOfMemory   =   -14000  #kModemOutOfMemory
kHIDBaseError   =   -13950  #kHIDBaseError
kHIDNullStateErr    =   -13949  #kHIDNullStateErr
kHIDBufferTooSmallErr   =   -13948  #kHIDBufferTooSmallErr
kHIDValueOutOfRangeErr  =   -13947  #kHIDValueOutOfRangeErr
kHIDUsageNotFoundErr    =   -13946  #kHIDUsageNotFoundErr
kHIDNotValueArrayErr    =   -13945  #kHIDNotValueArrayErr
kHIDInvalidPreparsedDataErr =   -13944  #kHIDInvalidPreparsedDataErr
kHIDIncompatibleReportErr   =   -13943  #kHIDIncompatibleReportErr
kHIDBadLogPhysValuesErr =   -13942  #kHIDBadLogPhysValuesErr
kHIDInvalidReportTypeErr    =   -13941  #kHIDInvalidReportTypeErr
kHIDInvalidReportLengthErr  =   -13940  #kHIDInvalidReportLengthErr
kHIDNullPointerErr  =   -13939  #kHIDNullPointerErr
kHIDBadParameterErr =   -13938  #kHIDBadParameterErr
kHIDNotEnoughMemoryErr  =   -13937  #kHIDNotEnoughMemoryErr
kHIDEndOfDescriptorErr  =   -13936  #kHIDEndOfDescriptorErr
kHIDUsagePageZeroErr    =   -13935  #kHIDUsagePageZeroErr
kHIDBadLogicalMinimumErr    =   -13934  #kHIDBadLogicalMinimumErr
kHIDBadLogicalMaximumErr    =   -13933  #kHIDBadLogicalMaximumErr
kHIDInvertedLogicalRangeErr =   -13932  #kHIDInvertedLogicalRangeErr
kHIDInvertedPhysicalRangeErr    =   -13931  #kHIDInvertedPhysicalRangeErr
kHIDUnmatchedUsageRangeErr  =   -13930  #kHIDUnmatchedUsageRangeErr
kHIDInvertedUsageRangeErr   =   -13929  #kHIDInvertedUsageRangeErr
kHIDUnmatchedStringRangeErr =   -13928  #kHIDUnmatchedStringRangeErr
kHIDUnmatchedDesignatorRangeErr =   -13927  #kHIDUnmatchedDesignatorRangeErr
kHIDReportSizeZeroErr   =   -13926  #kHIDReportSizeZeroErr
kHIDReportCountZeroErr  =   -13925  #kHIDReportCountZeroErr
kHIDReportIDZeroErr =   -13924  #kHIDReportIDZeroErr
kHIDInvalidRangePageErr =   -13923  #kHIDInvalidRangePageErr
kHIDDeviceNotReady  =   -13910  #The device is still initializing, try again later
kHIDVersionIncompatibleErr  =   -13909  #kHIDVersionIncompatibleErr
debuggingNoMatchErr =   -13887  #debugging component or option not found at this index
debuggingNoCallbackErr  =   -13886  #debugging component has no callback
debuggingInvalidNameErr =   -13885  #componentName or optionName is invalid (NULL)
debuggingInvalidOptionErr   =   -13884  #optionSelectorNum is not registered
debuggingInvalidSignatureErr    =   -13883  #componentSignature not registered
debuggingDuplicateOptionErr =   -13882  #optionSelectorNum already registered
debuggingDuplicateSignatureErr  =   -13881  #componentSignature already registered
debuggingExecutionContextErr    =   -13880  #routine cannot be called at this time
kBridgeSoftwareRunningCantSleep =   -13038  #kBridgeSoftwareRunningCantSleep
kNoSuchPowerSource  =   -13020  #kNoSuchPowerSource
kProcessorTempRoutineRequiresMPLib2 =   -13014  #kProcessorTempRoutineRequiresMPLib2
kCantReportProcessorTemperatureErr  =   -13013  #kCantReportProcessorTemperatureErr
kPowerMgtRequestDenied  =   -13010  #kPowerMgtRequestDenied
kPowerMgtMessageNotHandled  =   -13009  #kPowerMgtMessageNotHandled
kPowerHandlerNotFoundForProcErr =   -13008  #kPowerHandlerNotFoundForProcErr
kPowerHandlerNotFoundForDeviceErr   =   -13007  #kPowerHandlerNotFoundForDeviceErr
kPowerHandlerExistsForDeviceErr =   -13006  #kPowerHandlerExistsForDeviceErr
pmRecvEndErr    =   -13005  #during receive, pmgr did not finish hs configured for this connection
pmRecvStartErr  =   -13004  #during receive, pmgr did not start hs
pmSendEndErr    =   -13003  #during send, pmgr did not finish hs
pmSendStartErr  =   -13002  #during send, pmgr did not start hs
pmReplyTOErr    =   -13001  #Timed out waiting for reply
pmBusyErr   =   -13000  #Power Mgr never ready to start handshake
pictureDataErr  =   -11005  #the picture data was invalid
colorsRequestedErr  =   -11004  #the number of colors requested was illegal
cantLoadPickMethodErr   =   -11003  #unable to load the custom pick proc
pictInfoVerbErr =   -11002  #the passed verb was invalid
pictInfoIDErr   =   -11001  #the internal consistancy check for the PictInfoID is wrong
pictInfoVersionErr  =   -11000  #wrong version of the PictInfo structure
errTaskNotFound =   -10780  #no task with that task id exists
telNotEnoughdspBW   =   -10116  #not enough real-time for allocation
telBadSampleRate    =   -10115  #incompatible sample rate
telBadSWErr =   -10114  #Software not installed properly
telDetAlreadyOn =   -10113  #detection is already turned on
telAutoAnsNotOn =   -10112  #autoAnswer in not turned on
telValidateFailed   =   -10111  #telValidate failed
telBadProcID    =   -10110  #invalid procID
telDeviceNotFound   =   -10109  #device not found
telBadCodeResource  =   -10108  #code resource not found
telInitFailed   =   -10107  #initialization failed
telNoCommFolder =   -10106  #Communications/Extensions € not found
telUnknownErr   =   -10103  #unable to set config
telNoSuchTool   =   -10102  #unable to find tool with name specified
telBadFunction  =   -10091  #bad msgCode specified
telPBErr    =   -10090  #parameter block error, bad format
telCANotDeflectable =   -10082  #CA not "deflectable"
telCANotRejectable  =   -10081  #CA not "rejectable"
telCANotAcceptable  =   -10080  #CA not "acceptable"
telTermNotOpen  =   -10072  #terminal not opened via TELOpenTerm
telStillNeeded  =   -10071  #terminal driver still needed by someone else
telAlreadyOpen  =   -10070  #terminal already open
telNoCallbackRef    =   -10064  #no call back reference was specified, but is required
telDisplayModeNotSupp   =   -10063  #display mode not supported by tool
telBadDisplayMode   =   -10062  #bad display mode specified
telFwdTypeNotSupp   =   -10061  #forward type not supported by tool
telDNTypeNotSupp    =   -10060  #DN type not supported by tool
telBadRate  =   -10059  #bad rate specified
telBadBearerType    =   -10058  #bad bearerType specified
telBadSelect    =   -10057  #unable to select or deselect DN
telBadParkID    =   -10056  #bad park id specified
telBadPickupGroupID =   -10055  #bad pickup group ID specified
telBadFwdType   =   -10054  #bad fwdType specified
telBadFeatureID =   -10053  #bad feature ID specified
telBadIntercomID    =   -10052  #bad intercom ID specified
telBadPageID    =   -10051  #bad page ID specified
telBadDNType    =   -10050  #DN type invalid
telConfLimitExceeded    =   -10047  #attempt to exceed switch conference limits
telCBErr    =   -10046  #call back feature not set previously
telTransferRej  =   -10045  #transfer request rejected
telTransferErr  =   -10044  #transfer not prepared
telConfRej  =   -10043  #conference request was rejected
telConfErr  =   -10042  #conference was not prepared
telConfNoLimit  =   -10041  #no limit was specified but required
telConfLimitErr =   -10040  #limit specified is too high for this configuration
telFeatNotSupp  =   -10033  #feature program call not supported by this tool
telFeatActive   =   -10032  #feature already active
telFeatNotAvail =   -10031  #feature subscribed but not available
telFeatNotSub   =   -10030  #feature not subscribed
errAEPropertiesClash    =   -10025  #illegal combination of properties settings for Set Data, make new, or duplicate
errAECantPutThatThere   =   -10024  #in make new, duplicate, etc. class can't be an element of container
errAENotAnEnumMember    =   -10023  #enumerated value in SetData is not allowed for this property
telIntExtNotSupp    =   -10022  #internal external type not supported by this tool
telBadIntExt    =   -10021  #bad internal external error
telStateNotSupp =   -10020  #device state not supported by tool
telBadStateErr  =   -10019  #bad device state specified
telIndexNotSupp =   -10018  #index not supported by this tool
telBadIndex =   -10017  #bad index specified
telAPattNotSupp =   -10016  #alerting pattern not supported by tool
telBadAPattErr  =   -10015  #bad alerting pattern specified
telVTypeNotSupp =   -10014  #volume type not supported by this tool
telBadVTypeErr  =   -10013  #bad volume type error
telBadLevelErr  =   -10012  #bad volume level setting
telHTypeNotSupp =   -10011  #hook type not supported by this tool
telBadHTypeErr  =   -10010  #bad hook type specified
errAECantSupplyType =   -10009  #errAECantSupplyType
telNoOpenErr    =   -10008  #unable to open terminal
telNoMemErr =   -10007  #no memory to allocate handle
errOSACantAssign    =   -10006  #Signaled when an object cannot be set in a container.
telBadProcErr   =   -10005  #bad msgProc specified
telBadHandErr   =   -10004  #bad handle specified
OSAIllegalAssign    =   -10003  #Signaled when an object can never be set in a container
telBadDNErr =   -10002  #TELDNHandle not found or invalid
telBadTermErr   =   -10001  #invalid TELHandle or handle not found
errAEEventFailed    =   -10000  #errAEEventFailed
cannotMoveAttachedController    =   -9999   #cannotMoveAttachedController
controllerHasFixedHeight    =   -9998   #controllerHasFixedHeight
cannotSetWidthOfAttachedController  =   -9997   #cannotSetWidthOfAttachedController
controllerBoundsNotExact    =   -9996   #controllerBoundsNotExact
editingNotAllowed   =   -9995   #editingNotAllowed
badControllerHeight =   -9994   #badControllerHeight
deviceCantMeetRequest   =   -9408   #deviceCantMeetRequest
seqGrabInfoNotAvailable =   -9407   #seqGrabInfoNotAvailable
badSGChannel    =   -9406   #badSGChannel
couldntGetRequiredComponent =   -9405   #couldntGetRequiredComponent
notEnoughDiskSpaceToGrab    =   -9404   #notEnoughDiskSpaceToGrab
notEnoughMemoryToGrab   =   -9403   #notEnoughMemoryToGrab
cantDoThatInCurrentMode =   -9402   #cantDoThatInCurrentMode
grabTimeComplete    =   -9401   #grabTimeComplete
noDeviceForChannel  =   -9400   #noDeviceForChannel
kNoCardBusCISErr    =   -9109   #No valid CIS exists for this CardBus card
kNotZVCapableErr    =   -9108   #This socket does not support Zoomed Video
kCardPowerOffErr    =   -9107   #Power to the card has been turned off
kAttemptDupCardEntryErr =   -9106   #The Enabler was asked to create a duplicate card entry
kAlreadySavedStateErr   =   -9105   #The state has been saved on previous call
kTooManyIOWindowsErr    =   -9104   #device requested more than one I/O window
kNotReadyErr    =   -9103   #PC Card failed to go ready
kClientRequestDenied    =   -9102   #CS Clients should return this code inorder to
kNoCompatibleNameErr    =   -9101   #There is no compatible driver name for this device
kNoEnablerForCardErr    =   -9100   #No Enablers were found that can support the card
kNoCardEnablersFoundErr =   -9099   #No Enablers were found
kUnsupportedCardErr =   -9098   #Card not supported by generic enabler
kNoClientTableErr   =   -9097   #The client table has not be initialized yet
kNoMoreInterruptSlotsErr    =   -9096   #All internal Interrupt slots are in use
kNoMoreTimerClientsErr  =   -9095   #All timer callbacks are in use
kNoIOWindowRequestedErr =   -9094   #Request I/O window before calling configuration
kBadCustomIFIDErr   =   -9093   #Custom interface ID is invalid
kBadTupleDataErr    =   -9092   #Data in tuple is invalid
kInvalidCSClientErr =   -9091   #Card Services ClientID is not registered
kUnsupportedVsErr   =   -9090   #Unsupported Voltage Sense
kInvalidDeviceNumber    =   -9089   #kInvalidDeviceNumber
kPostCardEventErr   =   -9088   #_PCCSLPostCardEvent failed and dropped an event
kCantConfigureCardErr   =   -9087   #kCantConfigureCardErr
kPassCallToChainErr =   -9086   #kPassCallToChainErr
kCardBusCardErr =   -9085   #kCardBusCardErr
k16BitCardErr   =   -9084   #k16BitCardErr
kBadDeviceErr   =   -9083   #kBadDeviceErr
kBadLinkErr =   -9082   #kBadLinkErr
kInvalidRegEntryErr =   -9081   #kInvalidRegEntryErr
kNoCardSevicesSocketsErr    =   -9080   #kNoCardSevicesSocketsErr
kOutOfResourceErr   =   -9079   #Card Services has exhausted the resource
kNoMoreItemsErr =   -9078   #there are no more of the requested item
kInUseErr   =   -9077   #requested resource is being used by a client
kConfigurationLockedErr =   -9076   #a configuration has already been locked
kWriteProtectedErr  =   -9075   #media is write-protected
kBusyErr    =   -9074   #unable to process request at this time - try later
kUnsupportedModeErr =   -9073   #mode is not supported
kUnsupportedFunctionErr =   -9072   #function is not supported by this implementation
kNoCardErr  =   -9071   #no PC card in the socket
kGeneralFailureErr  =   -9070   #an undefined error has occurred
kWriteFailureErr    =   -9069   #unable to complete write request
kReadFailureErr =   -9068   #unable to complete read request
kBadSpeedErr    =   -9067   #specified speed is unavailable
kBadCISErr  =   -9066   #CIS on card is invalid
kBadHandleErr   =   -9065   #clientHandle is invalid
kBadArgsErr =   -9064   #values in argument packet are invalid
kBadArgLengthErr    =   -9063   #ArgLength argument is invalid
kBadWindowErr   =   -9062   #specified window is invalid
kBadVppErr  =   -9061   #specified Vpp1 or Vpp2 power level index is invalid
kBadVccErr  =   -9060   #specified Vcc power level index is invalid
kBadTypeErr =   -9059   #specified window or interface type is invalid
kBadSocketErr   =   -9058   #specified logical or physical socket number is invalid
kBadSizeErr =   -9057   #specified size is invalid
kBadPageErr =   -9056   #specified page is invalid
kBadOffsetErr   =   -9055   #specified PC card memory array offset is invalid
kBadIRQErr  =   -9054   #specified IRQ level is invalid
kBadEDCErr  =   -9053   #specified EDC generator specified is invalid
kBadBaseErr =   -9052   #specified base system memory address is invalid
kBadAttributeErr    =   -9051   #specified attributes field value is invalid
kBadAdapterErr  =   -9050   #invalid adapter number
codecOffscreenFailedPleaseRetryErr  =   -8992   #codecOffscreenFailedPleaseRetryErr
lockPortBitsWrongGDeviceErr =   -8991   #lockPortBitsWrongGDeviceErr
directXObjectAlreadyExists  =   -8990   #directXObjectAlreadyExists
codecDroppedFrameErr    =   -8989   #returned from ImageCodecDrawBand
codecOffscreenFailedErr =   -8988   #codecOffscreenFailedErr
codecNeedAccessKeyErr   =   -8987   #codec needs password in order to decompress
codecParameterDialogConfirm =   -8986   #codecParameterDialogConfirm
lockPortBitsSurfaceLostErr  =   -8985   #lockPortBitsSurfaceLostErr
lockPortBitsBadPortErr  =   -8984   #lockPortBitsBadPortErr
lockPortBitsWindowClippedErr    =   -8983   #lockPortBitsWindowClippedErr
lockPortBitsWindowResizedErr    =   -8982   #lockPortBitsWindowResizedErr
lockPortBitsWindowMovedErr  =   -8981   #lockPortBitsWindowMovedErr
lockPortBitsBadSurfaceErr   =   -8980   #lockPortBitsBadSurfaceErr
codecNeedToFlushChainErr    =   -8979   #codecNeedToFlushChainErr
codecDisabledErr    =   -8978   #codec disabled itself -- pass codecFlagReenable to reset
codecNoMemoryPleaseWaitErr  =   -8977   #codecNoMemoryPleaseWaitErr
codecNothingToBlitErr   =   -8976   #codecNothingToBlitErr
codecCantQueueErr   =   -8975   #codecCantQueueErr
codecCantWhenErr    =   -8974   #codecCantWhenErr
codecOpenErr    =   -8973   #codecOpenErr
codecConditionErr   =   -8972   #codecConditionErr
codecExtensionNotFoundErr   =   -8971   #codecExtensionNotFoundErr
codecDataVersErr    =   -8970   #codecDataVersErr
codecBadDataErr =   -8969   #codecBadDataErr
codecWouldOffscreenErr  =   -8968   #codecWouldOffscreenErr
codecAbortErr   =   -8967   #codecAbortErr
codecSpoolErr   =   -8966   #codecSpoolErr
codecImageBufErr    =   -8965   #codecImageBufErr
codecScreenBufErr   =   -8964   #codecScreenBufErr
codecSizeErr    =   -8963   #codecSizeErr
codecUnimpErr   =   -8962   #codecUnimpErr
noCodecErr  =   -8961   #noCodecErr
codecErr    =   -8960   #codecErr
kIllegalClockValueErr   =   -8852   #kIllegalClockValueErr
kUTCOverflowErr =   -8851   #kUTCOverflowErr
kUTCUnderflowErr    =   -8850   #kUTCUnderflowErr
kATSULastErr    =   -8809   #The last ATSUI error code.
kATSULineBreakInWord    =   -8808   #This is not an error code but is returned by ATSUBreakLine to
kATSUCoordinateOverflowErr  =   -8807   #Used to indicate the coordinates provided to an ATSUI routine caused
kATSUNoFontScalerAvailableErr   =   -8806   #Used when no font scaler is available for the font passed
kATSUNoFontCmapAvailableErr =   -8805   #Used when no CMAP table can be accessed or synthesized for the
kATSULowLevelErr    =   -8804   #Used when an error was encountered within the low level ATS
kATSUQuickDrawTextErr   =   -8803   #Used when QuickDraw Text encounters an error rendering or measuring
kATSUNoStyleRunsAssignedErr =   -8802   #Used when an attempt was made to measure, highlight or draw
kATSUNotSetErr  =   -8801   #Used when the client attempts to retrieve an attribute,
kATSUInvalidCacheErr    =   -8800   #Used when an attempt was made to read in style data
kATSUInvalidAttributeTagErr =   -8799   #Used when an attempt was made to use a tag value that
kATSUInvalidAttributeSizeErr    =   -8798   #Used when an attempt was made to use an attribute with a
kATSUInvalidAttributeValueErr   =   -8797   #Used when an attempt was made to use an attribute with
kATSUInvalidFontErr =   -8796   #Used when an attempt was made to use an invalid font ID.
kATSUNoCorrespondingFontErr =   -8795   #This value is retrned by font ID conversion
kATSUFontsNotMatched    =   -8794   #This value is returned by ATSUMatchFontsToText()
kATSUFontsMatched   =   -8793   #This is not an error code but is returned by
kATSUInvalidTextRangeErr    =   -8792   #An attempt was made to extract information
kATSUInvalidStyleErr    =   -8791   #An attempt was made to use a ATSUStyle which
kATSUInvalidTextLayoutErr   =   -8790   #An attempt was made to use a ATSUTextLayout
kTECOutputBufferFullStatus  =   -8785   #output buffer has no room for conversion of next input text element (partial conversion)
kTECNeedFlushStatus =   -8784   #kTECNeedFlushStatus
kTECUsedFallbacksStatus =   -8783   #kTECUsedFallbacksStatus
kTECItemUnavailableErr  =   -8771   #item (e.g. name) not available for specified region (& encoding if relevant)
kTECGlobalsUnavailableErr   =   -8770   #globals have already been deallocated (premature TERM)
unicodeChecksumErr  =   -8769   #unicodeChecksumErr
unicodeNoTableErr   =   -8768   #unicodeNoTableErr
unicodeVariantErr   =   -8767   #unicodeVariantErr
unicodeFallbacksErr =   -8766   #unicodeFallbacksErr
unicodePartConvertErr   =   -8765   #unicodePartConvertErr
unicodeBufErr   =   -8764   #unicodeBufErr
unicodeCharErr  =   -8763   #unicodeCharErr
unicodeElementErr   =   -8762   #unicodeElementErr
unicodeNotFoundErr  =   -8761   #unicodeNotFoundErr
unicodeTableFormatErr   =   -8760   #unicodeTableFormatErr
unicodeDirectionErr =   -8759   #unicodeDirectionErr
unicodeContextualErr    =   -8758   #unicodeContextualErr
unicodeTextEncodingDataErr  =   -8757   #unicodeTextEncodingDataErr
kTECDirectionErr    =   -8756   #direction stack overflow, etc.
kTECIncompleteElementErr    =   -8755   #text element may be incomplete or is too long for internal buffers
kTECUnmappableElementErr    =   -8754   #kTECUnmappableElementErr
kTECPartialCharErr  =   -8753   #input buffer ends in the middle of a multibyte character, conversion stopped
kTECBadTextRunErr   =   -8752   #kTECBadTextRunErr
kTECArrayFullErr    =   -8751   #supplied name buffer or TextRun, TextEncoding, or UnicodeMapping array is too small
kTECBufferBelowMinimumSizeErr   =   -8750   #output buffer too small to allow processing of first input text element
kTECNoConversionPathErr =   -8749   #kTECNoConversionPathErr
kTECCorruptConverterErr =   -8748   #invalid converter object reference
kTECTableFormatErr  =   -8747   #kTECTableFormatErr
kTECTableChecksumErr    =   -8746   #kTECTableChecksumErr
kTECMissingTableErr =   -8745   #kTECMissingTableErr
kTextUndefinedElementErr    =   -8740   #text conversion errors
kTextMalformedInputErr  =   -8739   #in DBCS, for example, high byte followed by invalid low byte
kTextUnsupportedEncodingErr =   -8738   #specified encoding not supported for this operation
kRANotEnabled   =   -7139   #kRANotEnabled
kRACallBackFailed   =   -7138   #kRACallBackFailed
kRADuplicateIPAddr  =   -7137   #kRADuplicateIPAddr
kRANCPRejectedbyPeer    =   -7136   #kRANCPRejectedbyPeer
kRAExtAuthenticationFailed  =   -7135   #kRAExtAuthenticationFailed
kRAATalkInactive    =   -7134   #kRAATalkInactive
kRAPeerNotResponding    =   -7133   #kRAPeerNotResponding
kRAPPPPeerDisconnected  =   -7132   #kRAPPPPeerDisconnected
kRAPPPUserDisconnected  =   -7131   #kRAPPPUserDisconnected
kRAPPPNegotiationFailed =   -7130   #kRAPPPNegotiationFailed
kRAPPPAuthenticationFailed  =   -7129   #kRAPPPAuthenticationFailed
kRAPPPProtocolRejected  =   -7128   #kRAPPPProtocolRejected
dcmBufferOverflowErr    =   -7127   #data is larger than buffer size
kRANotPrimaryInterface  =   -7126   #when IPCP is not primary TCP/IP intf.
kRATCPIPNotConfigured   =   -7125   #TCP/IP not configured, could be loaded
kRATCPIPInactive    =   -7124   #TCP/IP inactive, cannot be loaded
kRARemoteAccessNotReady =   -7123   #kRARemoteAccessNotReady
kRAInitOpenTransportFailed  =   -7122   #kRAInitOpenTransportFailed
dcmProtectedErr =   -7121   #need keyword to use dictionary
kRAUserPwdEntryRequired =   -7120   #kRAUserPwdEntryRequired
kRAUserPwdChangeRequired    =   -7119   #kRAUserPwdChangeRequired
dcmBadFindMethodErr =   -7118   #no such find method supported
kRAInvalidSerialProtocol    =   -7117   #kRAInvalidSerialProtocol
kRAInvalidPortState =   -7116   #kRAInvalidPortState
dcmBadKeyErr    =   -7115   #bad key information
kRAPortBusy =   -7114   #kRAPortBusy
kRAInstallationDamaged  =   -7113   #kRAInstallationDamaged
dcmBadFieldTypeErr  =   -7112   #no such field type supported
dcmBadFieldInfoErr  =   -7111   #incomplete information
dcmNecessaryFieldErr    =   -7110   #lack required/identify field
dcmDupRecordErr =   -7109   #same record already exist
kRANotConnected =   -7108   #kRANotConnected
dcmBlockFullErr =   -7107   #dictionary block full
kRAMissingResources =   -7106   #kRAMissingResources
dcmDictionaryBusyErr    =   -7105   #dictionary is busy
dcmDictionaryNotOpenErr =   -7104   #dictionary not opened
dcmPermissionErr    =   -7103   #invalid permission
dcmBadDictionaryErr =   -7102   #invalid dictionary
dcmNotDictionaryErr =   -7101   #not dictionary
kRAInvalidParameter =   -7100   #kRAInvalidParameter
laEngineNotFoundErr =   -7000   #can't find the engine
laPropertyErr   =   -6999   #Error in properties
kUSBUnknownDeviceErr    =   -6998   #device ref not recognised
laPropertyIsReadOnlyErr =   -6997   #the property is read only
laPropertyUnknownErr    =   -6996   #the property is unknown to this environment
laPropertyValueErr  =   -6995   #Invalid property value
laDictionaryTooManyErr  =   -6994   #too many dictionaries
laDictionaryUnknownErr  =   -6993   #can't use this dictionary with this environment
laDictionaryNotOpenedErr    =   -6992   #the dictionary is not opened
laTextOverFlowErr   =   -6991   #text is too long
laFailAnalysisErr   =   -6990   #analysis failed
laNoMoreMorphemeErr =   -6989   #nothing to read
laInvalidPathErr    =   -6988   #path is not correct
kUSBNotHandled  =   -6987   #Notification was not handled   (same as NotFound)
laEnvironmentNotFoundErr    =   -6986   #can't fint the specified environment
laEnvironmentBusyErr    =   -6985   #specified environment is used
laTooSmallBufferErr =   -6984   #output buffer is too small to store any result
kUSBFlagsError  =   -6983   #Unused flags not zeroed
kUSBAbortedError    =   -6982   #Pipe aborted
kUSBNoBandwidthError    =   -6981   #Not enough bandwidth available
kUSBPipeIdleError   =   -6980   #Pipe is Idle, it will not accept transactions
kUSBPipeStalledError    =   -6979   #Pipe has stalled, error needs to be cleared
kUSBUnknownInterfaceErr =   -6978   #Interface ref not recognised
kUSBDeviceBusy  =   -6977   #Device is already being configured
kUSBDevicePowerProblem  =   -6976   #Device has a power problem
kUSBInvalidBuffer   =   -6975   #bad buffer, usually nil
kUSBDeviceSuspended =   -6974   #Device is suspended
kUSBDeviceNotSuspended  =   -6973   #device is not suspended for resume
kUSBDeviceDisconnected  =   -6972   #Disconnected during suspend or reset
kUSBTimedOut    =   -6971   #Transaction timed out.
kUSBQueueAborted    =   -6970   #Pipe zero stall cleared.
kUSBPortDisabled    =   -6969   #The port you are attached to is disabled, use USBDeviceReset.
kUSBBadDispatchTable    =   -6950   #Improper driver dispatch table
kUSBUnknownNotification =   -6949   #Notification type not defined
kUSBQueueFull   =   -6948   #Internal queue maxxed
kUSBLinkErr =   -6916   #kUSBLinkErr
kUSBCRCErr  =   -6915   #Pipe stall, bad CRC
kUSBBitstufErr  =   -6914   #Pipe stall, bitstuffing
kUSBDataToggleErr   =   -6913   #Pipe stall, Bad data toggle
kUSBEndpointStallErr    =   -6912   #Device didn't understand
kUSBNotRespondingErr    =   -6911   #Pipe stall, No device, device hung
kUSBPIDCheckErr =   -6910   #Pipe stall, PID CRC error
kUSBWrongPIDErr =   -6909   #Pipe stall, Bad or wrong PID
kUSBOverRunErr  =   -6908   #Packet too large or more data than buffer
kUSBUnderRunErr =   -6907   #Less data than buffer
kUSBRes1Err =   -6906   #kUSBRes1Err
kUSBRes2Err =   -6905   #kUSBRes2Err
kUSBBufOvrRunErr    =   -6904   #Host hardware failure on data in, PCI busy?
kUSBBufUnderRunErr  =   -6903   #Host hardware failure on data out, PCI busy?
kUSBNotSent1Err =   -6902   #Transaction not sent
kUSBNotSent2Err =   -6901   #Transaction not sent
kDMFoundErr =   -6232   #Did not proceed because we found an item
kDMMainDisplayCannotMoveErr =   -6231   #Trying to move main display (or a display mirrored to it)
kDMDisplayAlreadyInstalledErr   =   -6230   #Attempt to add an already installed display.
kDMDisplayNotFoundErr   =   -6229   #Could not find item (will someday remove).
kDMDriverNotDisplayMgrAwareErr  =   -6228   #Video Driver does not support display manager.
kDMSWNotInitializedErr  =   -6227   #Required software not initialized (eg windowmanager or display mgr).
kSysSWTooOld    =   -6226   #Missing critical pieces of System Software.
kDMMirroringNotOn   =   -6225   #Returned by all calls that need mirroring to be on to do their thing.
kDMCantBlock    =   -6224   #Mirroring is already on, canŐt Block now (call DMUnMirror() first).
kDMMirroringBlocked =   -6223   #DMBlockMirroring() has been called.
kDMWrongNumberOfDisplays    =   -6222   #Can only handle 2 displays for now.
kDMMirroringOnAlready   =   -6221   #Returned by all calls that need mirroring to be off to do their thing.
kDMGenErr   =   -6220   #Unexpected Error
kQTSSUnknownErr =   -6150   #kQTSSUnknownErr
collectionVersionErr    =   -5753   #collectionVersionErr
collectionIndexRangeErr =   -5752   #collectionIndexRangeErr
collectionItemNotFoundErr   =   -5751   #collectionItemNotFoundErr
collectionItemLockedErr =   -5750   #collectionItemLockedErr
kNavMissingKindStringErr    =   -5699   #kNavMissingKindStringErr
kNavInvalidCustomControlMessageErr  =   -5698   #kNavInvalidCustomControlMessageErr
kNavCustomControlMessageFailedErr   =   -5697   #kNavCustomControlMessageFailedErr
kNavInvalidSystemConfigErr  =   -5696   #kNavInvalidSystemConfigErr
kNavWrongDialogClassErr =   -5695   #kNavWrongDialogClassErr
kNavWrongDialogStateErr =   -5694   #kNavWrongDialogStateErr
dialogNoTimeoutErr  =   -5640   #dialogNoTimeoutErr
menuInvalidErr  =   -5623   #menu is invalid
menuItemNotFoundErr =   -5622   #specified menu item wasn't found
menuUsesSystemDefErr    =   -5621   #GetMenuDefinition failed because the menu uses the system MDEF
menuNotFoundErr =   -5620   #specified menu or menu ID wasn't found
windowWrongStateErr =   -5615   #window is not in a state that is valid for the current action
windowManagerInternalErr    =   -5614   #something really weird happened inside the window manager
windowAttributesConflictErr =   -5613   #passed some attributes that are mutually exclusive
windowAttributeImmutableErr =   -5612   #tried to change attributes which can't be changed
errWindowDoesNotFitOnscreen =   -5611   #ConstrainWindowToScreen could not make the window fit onscreen
errWindowNotFound   =   -5610   #returned from FindWindowOfClass
errFloatingWindowsNotInitialized    =   -5609   #called HideFloatingWindows or ShowFloatingWindows without calling InitFloatingWindows
errWindowsAlreadyInitialized    =   -5608   #tried to call InitFloatingWindows twice, or called InitWindows and then floating windows
errUserWantsToDragWindow    =   -5607   #if returned from TrackWindowProxyDrag, you should call DragWindow on the window
errCorruptWindowDescription =   -5606   #tried to load a corrupt window description (size or version fields incorrect)
errUnrecognizedWindowClass  =   -5605   #tried to create a window with a bad WindowClass
errWindowPropertyNotFound   =   -5604   #tried to get a nonexistent property
errInvalidWindowProperty    =   -5603   #tried to access a property tag with private creator
errWindowDoesNotHaveProxy   =   -5602   #tried to do something requiring a proxy to a window which doesnŐt have a proxy
errUnsupportedWindowAttributesForClass  =   -5601   #tried to create a window with WindowAttributes not supported by the WindowClass
errInvalidWindowPtr =   -5600   #tried to pass a bad WindowRef argument
gestaltLocationErr  =   -5553   #gestalt function ptr wasn't in sysheap
gestaltDupSelectorErr   =   -5552   #tried to add an entry that already existed
gestaltUndefSelectorErr =   -5551   #undefined selector was passed to Gestalt
gestaltUnknownErr   =   -5550   #value returned if Gestalt doesn't know the answer
envVersTooBig   =   -5502   #Version bigger than call can handle
envBadVers  =   -5501   #Version non-positive
envNotPresent   =   -5500   #returned by glue.
qtsAddressBusyErr   =   -5421   #qtsAddressBusyErr
qtsConnectionFailedErr  =   -5420   #qtsConnectionFailedErr
qtsTimeoutErr   =   -5408   #qtsTimeoutErr
qtsUnknownValueErr  =   -5407   #qtsUnknownValueErr
qtsTooMuchDataErr   =   -5406   #qtsTooMuchDataErr
qtsUnsupportedFeatureErr    =   -5405   #qtsUnsupportedFeatureErr
qtsUnsupportedRateErr   =   -5404   #qtsUnsupportedRateErr
qtsUnsupportedDataTypeErr   =   -5403   #qtsUnsupportedDataTypeErr
qtsBadDataErr   =   -5402   #something is wrong with the data
qtsBadStateErr  =   -5401   #qtsBadStateErr
qtsBadSelectorErr   =   -5400   #qtsBadSelectorErr
errIAEndOfTextRun   =   -5388   #errIAEndOfTextRun
errIATextExtractionErr  =   -5387   #errIATextExtractionErr
errIAInvalidDocument    =   -5386   #errIAInvalidDocument
errIACanceled   =   -5385   #errIACanceled
errIABufferTooSmall =   -5384   #errIABufferTooSmall
errIANoMoreItems    =   -5383   #errIANoMoreItems
errIAParamErr   =   -5382   #errIAParamErr
errIAAllocationErr  =   -5381   #errIAAllocationErr
errIAUnknownErr =   -5380   #errIAUnknownErr
hrURLNotHandledErr  =   -5363   #hrURLNotHandledErr
hrUnableToResizeHandleErr   =   -5362   #hrUnableToResizeHandleErr
hrMiscellaneousExceptionErr =   -5361   #hrMiscellaneousExceptionErr
hrHTMLRenderingLibNotInstalledErr   =   -5360   #hrHTMLRenderingLibNotInstalledErr
errCannotUndo   =   -5253   #errCannotUndo
errNonContiuousAttribute    =   -5252   #errNonContiuousAttribute
errUnknownElement   =   -5251   #errUnknownElement
errReadOnlyText =   -5250   #errReadOnlyText
errEmptyScrap   =   -5249   #errEmptyScrap
errNoHiliteText =   -5248   #errNoHiliteText
errOffsetNotOnElementBounday    =   -5247   #errOffsetNotOnElementBounday
errInvalidRange =   -5246   #errInvalidRange
errIteratorReachedEnd   =   -5245   #errIteratorReachedEnd
errEngineNotFound   =   -5244   #errEngineNotFound
errAlreadyInImagingMode =   -5243   #errAlreadyInImagingMode
errNotInImagingMode =   -5242   #errNotInImagingMode
errMarginWilllNotFit    =   -5241   #errMarginWilllNotFit
errUnknownAttributeTag  =   -5240   #errUnknownAttributeTag
afpSameNodeErr  =   -5063   #An Attempt was made to connect to a file server running on the same machine
afpAlreadyMounted   =   -5062   #The volume is already mounted
afpCantMountMoreSrvre   =   -5061   #The Maximum number of server connections has been reached
afpBadDirIDType =   -5060   #afpBadDirIDType
afpCallNotAllowed   =   -5048   #The server knows what you wanted to do, but won't let you do it just now
afpAlreadyLoggedInErr   =   -5047   #User has been authenticated but is already logged in from another machine (and that's not allowed on this server)
afpPwdPolicyErr =   -5046   #Password does not conform to servers password policy
afpPwdNeedsChangeErr    =   -5045   #The password needs to be changed
afpInsideTrashErr   =   -5044   #The folder being shared is inside the trash folder OR the shared folder is being moved into the trash folder
afpInsideSharedErr  =   -5043   #The folder being shared is inside a shared folder OR the folder contains a shared folder and is being moved into a shared folder
afpPwdExpiredErr    =   -5042   #The password being used is too old: this requires the user to change the password before log-in can continue
afpPwdTooShortErr   =   -5041   #The password being set is too short: there is a minimum length that must be met or exceeded
afpPwdSameErr   =   -5040   #Someone tried to change their password to the same password on a mantadory password change
afpBadIDErr =   -5039   #afpBadIDErr
afpSameObjectErr    =   -5038   #afpSameObjectErr
afpCatalogChanged   =   -5037   #afpCatalogChanged
afpDiffVolErr   =   -5036   #afpDiffVolErr
afpIDExists =   -5035   #afpIDExists
afpIDNotFound   =   -5034   #afpIDNotFound
afpContainsSharedErr    =   -5033   #the folder being shared contains a shared folder
afpObjectLocked =   -5032   #Object is M/R/D/W inhibited
afpVolLocked    =   -5031   #Volume is Read-Only
afpIconTypeError    =   -5030   #Icon size specified different from existing icon size
afpDirNotFound  =   -5029   #Unknown directory specified
afpCantRename   =   -5028   #AFPRename cannot rename volume
afpServerGoingDown  =   -5027   #Server is shutting down
afpTooManyFilesOpen =   -5026   #Maximum open file count reached
afpObjectTypeErr    =   -5025   #File/Directory specified where Directory/File expected
afpCallNotSupported =   -5024   #Unsupported AFP call was made
afpUserNotAuth  =   -5023   #No AFPLogin call has successfully been made for this session
afpSessClosed   =   -5022   #Session closed
afpRangeOverlap =   -5021   #Some or all of range already locked by same user
afpRangeNotLocked   =   -5020   #Tried to unlock range that was not locked by user
afpParmErr  =   -5019   #A specified parameter was out of allowable range
afpObjectNotFound   =   -5018   #Specified file or directory does not exist
afpObjectExists =   -5017   #Specified destination file or directory already exists
afpNoServer =   -5016   #Server not responding
afpNoMoreLocks  =   -5015   #Maximum lock limit reached
afpMiscErr  =   -5014   #Unexpected error encountered during execution
afpLockErr  =   -5013   #Some or all of requested range is locked by another user
afpItemNotFound =   -5012   #Unknown UserName/UserID or missing comment/APPL entry
afpFlatVol  =   -5011   #Cannot create directory on specified volume
afpFileBusy =   -5010   #Cannot delete an open file
afpEofError =   -5009   #Read beyond logical end-of-file
afpDiskFull =   -5008   #Insufficient free space on volume for operation
afpDirNotEmpty  =   -5007   #Cannot delete non-empty directory
afpDenyConflict =   -5006   #Specified open/deny modes conflict with current open modes
afpCantMove =   -5005   #Move destination is offspring of source, or root was specified
afpBitmapErr    =   -5004   #Bitmap contained bits undefined for call
afpBadVersNum   =   -5003   #Unknown AFP protocol version number specified
afpBadUAM   =   -5002   #Unknown user authentication method specified
afpAuthContinue =   -5001   #Further information required to complete AFPLogin call
afpAccessDenied =   -5000   #Insufficient access privileges for operation
illegalScrapFlavorSizeErr   =   -4999   #illegalScrapFlavorSizeErr
illegalScrapFlavorTypeErr   =   -4998   #illegalScrapFlavorTypeErr
illegalScrapFlavorFlagsErr  =   -4997   #illegalScrapFlavorFlagsErr
scrapFlavorSizeMismatchErr  =   -4996   #scrapFlavorSizeMismatchErr
scrapFlavorFlagsMismatchErr =   -4995   #scrapFlavorFlagsMismatchErr
nilScrapFlavorDataErr   =   -4994   #nilScrapFlavorDataErr
noScrapPromiseKeeperErr =   -4993   #noScrapPromiseKeeperErr
scrapPromiseNotKeptErr  =   -4992   #scrapPromiseNotKeptErr
processStateIncorrectErr    =   -4991   #processStateIncorrectErr
badScrapRefErr  =   -4990   #badScrapRefErr
duplicateScrapFlavorErr =   -4989   #duplicateScrapFlavorErr
internalScrapErr    =   -4988   #internalScrapErr
coreFoundationUnknownErr    =   -4960   #coreFoundationUnknownErr
badRoutingSizeErr   =   -4276   #badRoutingSizeErr
routingNotFoundErr  =   -4275   #routingNotFoundErr
duplicateRoutingErr =   -4274   #duplicateRoutingErr
invalidFolderTypeErr    =   -4273   #invalidFolderTypeErr
noMoreFolderDescErr =   -4272   #noMoreFolderDescErr
duplicateFolderDescErr  =   -4271   #duplicateFolderDescErr
badFolderDescErr    =   -4270   #badFolderDescErr
cmCantGamutCheckError   =   -4217   #Gammut checking not supported by this ColorWorld
cmNamedColorNotFound    =   -4216   #NamedColor not found
cmCantCopyModifiedV1Profile =   -4215   #Illegal to copy version 1 profiles that have been modified
cmRangeOverFlow =   -4214   #Color conversion warning that some output color values over/underflowed and were clipped
cmInvalidProfileComment =   -4213   #Bad Profile comment during drawpicture
cmNoGDevicesError   =   -4212   #Begin/End Matching -- no gdevices available
cmInvalidDstMap =   -4211   #Destination pix/bit map was invalid
cmInvalidSrcMap =   -4210   #Source pix/bit map was invalid
cmInvalidColorSpace =   -4209   #Profile colorspace does not match bitmap type
cmErrIncompatibleProfile    =   -4208   #Other ColorSync Errors
cmSearchError   =   -4207   #cmSearchError
cmInvalidSearch =   -4206   #Bad Search Handle
cmInvalidProfileLocation    =   -4205   #Operation not supported for this profile location
cmInvalidProfile    =   -4204   #A Profile must contain a 'cs1 ' tag to be valid
cmFatalProfileErr   =   -4203   #cmFatalProfileErr
cmCantDeleteElement =   -4202   #cmCantDeleteElement
cmIndexRangeErr =   -4201   #Tag index out of range
kNSLInitializationFailed    =   -4200   #UNABLE TO INITIALIZE THE MANAGER!!!!! DO NOT CONTINUE!!!!
kNSLNotInitialized  =   -4199   #kNSLNotInitialized
kNSLInsufficientSysVer  =   -4198   #kNSLInsufficientSysVer
kNSLInsufficientOTVer   =   -4197   #kNSLInsufficientOTVer
kNSLNoElementsInList    =   -4196   #kNSLNoElementsInList
kNSLBadReferenceErr =   -4195   #kNSLBadReferenceErr
kNSLBadServiceTypeErr   =   -4194   #kNSLBadServiceTypeErr
kNSLBadDataTypeErr  =   -4193   #kNSLBadDataTypeErr
kNSLBadNetConnection    =   -4192   #kNSLBadNetConnection
kNSLNoSupportForService =   -4191   #kNSLNoSupportForService
kNSLInvalidPluginSpec   =   -4190   #kNSLInvalidPluginSpec
kNSLRequestBufferAlreadyInList  =   -4189   #kNSLRequestBufferAlreadyInList
kNSLNoContextAvailable  =   -4188   #(ContinueLookup function ptr invalid)
kNSLBufferTooSmallForData   =   -4187   #(Client buffer too small for data from plugin)
kNSLCannotContinueLookup    =   -4186   #(Can't continue lookup; error or bad state)
kNSLBadClientInfoPtr    =   -4185   #(nil ClientAsyncInfoPtr; no reference available)
kNSLNullListPtr =   -4184   #(client is trying to add items to a nil list)
kNSLBadProtocolTypeErr  =   -4183   #(client is trying to add a null protocol type)
kNSLPluginLoadFailed    =   -4182   #(manager unable to load one of the plugins)
kNSLNoPluginsFound  =   -4181   #(manager didn't find any valid plugins to load)
kNSLSearchAlreadyInProgress =   -4180   #(you can only have one ongoing search per clientRef)
kNSLNoPluginsForSearch  =   -4179   #(no plugins will respond to search request; bad protocol(s)?)
kNSLNullNeighborhoodPtr =   -4178   #(client passed a null neighborhood ptr)
kNSLSomePluginsFailedToLoad =   -4177   #(one or more plugins failed to load, but at least one did load; this error isn't fatal)
kNSLErrNullPtrError =   -4176   #kNSLErrNullPtrError
kNSLNotImplementedYet   =   -4175   #kNSLNotImplementedYet
kNSLUILibraryNotAvailable   =   -4174   #The NSL UI Library needs to be in the Extensions Folder
kNSLNoCarbonLib =   -4173   #kNSLNoCarbonLib
kNSLBadURLSyntax    =   -4172   #URL contains illegal characters
kNSLSchedulerError  =   -4171   #A custom thread routine encountered an error
kNSL68kContextNotSupported  =   -4170   #no 68k allowed
noHelpForItem   =   -4009   #noHelpForItem
badProfileError =   -4008   #badProfileError
colorSyncNotInstalled   =   -4007   #colorSyncNotInstalled
pickerCantLive  =   -4006   #pickerCantLive
cantLoadPackage =   -4005   #cantLoadPackage
cantCreatePickerWindow  =   -4004   #cantCreatePickerWindow
cantLoadPicker  =   -4003   #cantLoadPicker
pickerResourceError =   -4002   #pickerResourceError
requiredFlagsDontMatch  =   -4001   #requiredFlagsDontMatch
firstPickerError    =   -4000   #firstPickerError
kOTPortLostConnection   =   -3285   #
kOTUserRequestedErr =   -3284   #
kOTConfigurationChangedErr  =   -3283   #
kOTBadConfigurationErr  =   -3282   #
kOTPortWasEjectedErr    =   -3281   #
kOTPortHasDiedErr   =   -3280   #
kOTClientNotInittedErr  =   -3279   #
kENOMSGErr  =   -3278   #
kESRCHErr   =   -3277   #
kEINPROGRESSErr =   -3276   #
kENODATAErr =   -3275   #
kENOSTRErr  =   -3274   #
kECANCELErr =   -3273   #
kEBADMSGErr =   -3272   #
kENOSRErr   =   -3271   #
kETIMEErr   =   -3270   #
kEPROTOErr  =   -3269   #‚‚‚ fill out missing codes ‚‚‚
kEHOSTUNREACHErr    =   -3264   #No route to host
kEHOSTDOWNErr   =   -3263   #Host is down
kECONNREFUSEDErr    =   -3260   #Connection refused
kETIMEDOUTErr   =   -3259   #Connection timed out
kETOOMANYREFSErr    =   -3258   #Too many references: can't splice
kESHUTDOWNErr   =   -3257   #Can't send after socket shutdown
kENOTCONNErr    =   -3256   #Socket is not connected
kEISCONNErr =   -3255   #Socket is already connected
kENOBUFSErr =   -3254   #No buffer space available
kECONNRESETErr  =   -3253   #Connection reset by peer
kECONNABORTEDErr    =   -3252   #Software caused connection abort
kENETRESETErr   =   -3251   #Network dropped connection on reset
kENETUNREACHErr =   -3250   #Network is unreachable
kENETDOWNErr    =   -3249   #Network is down
kEADDRNOTAVAILErr   =   -3248   #Can't assign requested address
kEADDRINUSEErr  =   -3247   #Address already in use
kEOPNOTSUPPErr  =   -3244   #Operation not supported on socket
kESOCKTNOSUPPORTErr =   -3243   #Socket type not supported
kEPROTONOSUPPORTErr =   -3242   #Protocol not supported
kENOPROTOOPTErr =   -3241   #Protocol not available
kEPROTOTYPEErr  =   -3240   #Protocol wrong type for socket
kEMSGSIZEErr    =   -3239   #Message too long
kEDESTADDRREQErr    =   -3238   #Destination address required
kENOTSOCKErr    =   -3237   #Socket operation on non-socket
kEALREADYErr    =   -3236   #
kEWOULDBLOCKErr =   -3234   #Call would block, so was aborted
kERANGEErr  =   -3233   #Message size too large for STREAM
kEPIPEErr   =   -3231   #Broken pipe
kENOTTYErr  =   -3224   #Not a character device
kEINVALErr  =   -3221   #Invalid argument
kENODEVErr  =   -3218   #No such device
kOTDuplicateFoundErr    =   -3216   #OT generic duplicate found error
kEBUSYErr   =   -3215   #Device or resource busy
kEFAULTErr  =   -3213   #Bad address
kEACCESErr  =   -3212   #Permission denied
kOTOutOfMemoryErr   =   -3211   #OT ran out of memory, may be a temporary
kEAGAINErr  =   -3210   #Try operation again later
kEBADFErr   =   -3208   #Bad file number
kENXIOErr   =   -3205   #No such device or address
kEIOErr =   -3204   #I/O error
kEINTRErr   =   -3203   #Interrupted system service
kENORSRCErr =   -3202   #No such resource
kOTNotFoundErr  =   -3201   #OT generic not found error
kEPERMErr   =   -3200   #Permission denied
kOTCanceledErr  =   -3180   #XTI2OSStatus(TCANCELED) The command was cancelled
kOTBadSyncErr   =   -3179   #XTI2OSStatus(TBADSYNC) A synchronous call at interrupt time
kOTProtocolErr  =   -3178   #XTI2OSStatus(TPROTO) An unspecified provider error occurred
kOTQFullErr =   -3177   #XTI2OSStatus(TQFULL)
kOTResAddressErr    =   -3176   #XTI2OSStatus(TRESADDR)
kOTResQLenErr   =   -3175   #XTI2OSStatus(TRESQLEN)
kOTProviderMismatchErr  =   -3174   #XTI2OSStatus(TPROVMISMATCH) Tried to accept on incompatible endpoint
kOTIndOutErr    =   -3173   #XTI2OSStatus(TINDOUT) Accept failed because of pending listen
kOTAddressBusyErr   =   -3172   #XTI2OSStatus(TADDRBUSY) Address requested is already in use
kOTBadQLenErr   =   -3171   #XTI2OSStatus(TBADQLEN) A Bind to an in-use addr with qlen > 0
kOTBadNameErr   =   -3170   #XTI2OSStatus(TBADNAME) A bad endpoint name was supplied
kOTNoStructureTypeErr   =   -3169   #XTI2OSStatus(TNOSTRUCTYPE) Bad structure type requested for OTAlloc
kOTStateChangeErr   =   -3168   #XTI2OSStatus(TSTATECHNG) State is changing - try again later
kOTNotSupportedErr  =   -3167   #XTI2OSStatus(TNOTSUPPORT) Command is not supported
kOTNoReleaseErr =   -3166   #XTI2OSStatus(TNOREL) No orderly release indication available
kOTBadFlagErr   =   -3165   #XTI2OSStatus(TBADFLAG) A Bad flag value was supplied
kOTNoUDErrErr   =   -3164   #XTI2OSStatus(TNOUDERR) No Unit Data Error indication available
kOTNoDisconnectErr  =   -3163   #XTI2OSStatus(TNODIS) No disconnect indication available
kOTNoDataErr    =   -3162   #XTI2OSStatus(TNODATA) No data available for reading
kOTFlowErr  =   -3161   #XTI2OSStatus(TFLOW) Provider is flow-controlled
kOTBufferOverflowErr    =   -3160   #XTI2OSStatus(TBUFOVFLW) Passed buffer not big enough
kOTBadDataErr   =   -3159   #XTI2OSStatus(TBADDATA) An illegal amount of data was specified
kOTLookErr  =   -3158   #XTI2OSStatus(TLOOK) An event occurred - call Look()
kOTSysErrorErr  =   -3157   #XTI2OSStatus(TSYSERR) A system error occurred
kOTBadSequenceErr   =   -3156   #XTI2OSStatus(TBADSEQ) Sequence specified does not exist
kOTOutStateErr  =   -3155   #XTI2OSStatus(TOUTSTATE) Call issued in wrong state
kOTNoAddressErr =   -3154   #XTI2OSStatus(TNOADDR) No address was specified
kOTBadReferenceErr  =   -3153   #XTI2OSStatus(TBADF) Bad provider reference
kOTAccessErr    =   -3152   #XTI2OSStatus(TACCES) Missing access permission
kOTBadOptionErr =   -3151   #XTI2OSStatus(TBADOPT) A Bad option was specified
kOTBadAddressErr    =   -3150   #XTI2OSStatus(TBADADDR) A Bad address was specified
sktClosedErr    =   -3109   #sktClosedErr
recNotFnd   =   -3108   #recNotFnd
atpBadRsp   =   -3107   #atpBadRsp
atpLenErr   =   -3106   #atpLenErr
readQErr    =   -3105   #readQErr
extractErr  =   -3104   #extractErr
ckSumErr    =   -3103   #ckSumErr
noMPPErr    =   -3102   #noMPPErr
buf2SmallErr    =   -3101   #buf2SmallErr
noPrefAppErr    =   -3032   #noPrefAppErr
badTranslationSpecErr   =   -3031   #badTranslationSpecErr
noTranslationPathErr    =   -3030   #noTranslationPathErr
couldNotParseSourceFileErr  =   -3026   #Source document does not contain source type
invalidTranslationPathErr   =   -3025   #Source type to destination type not a valid path
retryComponentRegistrationErr   =   -3005   #retryComponentRegistrationErr
unresolvedComponentDLLErr   =   -3004   #unresolvedComponentDLLErr
componentDontRegister   =   -3003   #componentDontRegister
componentNotCaptured    =   -3002   #componentNotCaptured
validInstancesExist =   -3001   #validInstancesExist
invalidComponentID  =   -3000   #invalidComponentID
cfragLastErrCode    =   -2899   #The last value in the range of CFM errors.
cfragOutputLengthErr    =   -2831   #An output parameter is too small to hold the value.
cfragAbortClosureErr    =   -2830   #Used by notification handlers to abort a closure.
cfragClosureIDErr   =   -2829   #The closure ID was not valid.
cfragContainerIDErr =   -2828   #The fragment container ID was not valid.
cfragNoRegistrationErr  =   -2827   #The registration name was not found.
cfragNotClosureErr  =   -2826   #The closure ID was actually a connection ID.
cfragFileSizeErr    =   -2825   #A file was too large to be mapped.
cfragFragmentUsageErr   =   -2824   #A semantic error in usage of the fragment.
cfragArchitectureErr    =   -2823   #A fragment has an unacceptable architecture.
cfragNoApplicationErr   =   -2822   #No application member found in the cfrg resource.
cfragInitFunctionErr    =   -2821   #A fragment's initialization routine returned an error.
cfragFragmentCorruptErr =   -2820   #A fragment's container was corrupt (known format).
cfragCFMInternalErr =   -2819   #An internal inconstistancy has been detected.
cfragCFMStartupErr  =   -2818   #Internal error during CFM initialization.
cfragLibConnErr =   -2817   #
cfragInitAtBootErr  =   -2816   #A boot library has an initialization function.  (System 7 only)
cfragInitLoopErr    =   -2815   #Circularity in required initialization order.
cfragImportTooNewErr    =   -2814   #An import library was too new for a client.
cfragImportTooOldErr    =   -2813   #An import library was too old for a client.
cfragInitOrderErr   =   -2812   #
cfragNoIDsErr   =   -2811   #No more CFM IDs for contexts, connections, etc.
cfragNoClientMemErr =   -2810   #Out of memory for fragment mapping or section instances.
cfragNoPrivateMemErr    =   -2809   #Out of memory for internal bookkeeping.
cfragNoPositionErr  =   -2808   #The registration insertion point was not found.
cfragUnresolvedErr  =   -2807   #A fragment had "hard" unresolved imports.
cfragFragmentFormatErr  =   -2806   #A fragment's container format is unknown.
cfragDupRegistrationErr =   -2805   #The registration name was already in use.
cfragNoLibraryErr   =   -2804   #The named library was not found.
cfragNoSectionErr   =   -2803   #The specified section was not found.
cfragNoSymbolErr    =   -2802   #The specified symbol was not found.
cfragConnectionIDErr    =   -2801   #The connection ID was not valid.
cfragFirstErrCode   =   -2800   #The first value in the range of CFM errors.
errASInconsistentNames  =   -2780   #English errors:
errASNoResultReturned   =   -2763   #The range -2780 thru -2799 is reserved for dialect specific error codes. (Error codes from different dialects may overlap.)
errASParameterNotForEvent   =   -2762   #errASParameterNotForEvent
errASIllegalFormalParameter =   -2761   #errASIllegalFormalParameter
errASTerminologyNestingTooDeep  =   -2760   #errASTerminologyNestingTooDeep
OSAControlFlowError =   -2755   #Signaled when illegal control flow occurs in an application (no catcher for throw, non-lexical loop exit, etc.)
OSAInconsistentDeclarations =   -2754   #Signaled when a variable is declared inconsistently in the same scope, such as both local and global
OSAUndefinedVariable    =   -2753   #Signaled when a variable is accessed that has no value
OSADuplicateHandler =   -2752   #Signaled when more than one handler is defined with the same name in a scope where the language doesn't allow it
OSADuplicateProperty    =   -2751   #Signaled when a formal parameter, local variable, or instance variable is specified more than once.
OSADuplicateParameter   =   -2750   #Signaled when a formal parameter, local variable, or instance variable is specified more than once
OSATokenTooLong =   -2742   #Signaled when a name or number is too long to be parsed
OSASyntaxTypeError  =   -2741   #Signaled when another form of syntax was expected. (e.g. "expected a <type> but found <this>")
OSASyntaxError  =   -2740   #Signaled when a syntax error occurs. (e.g. "Syntax error" or "<this> can't go after <that>")
errASCantCompareMoreThan32k =   -2721   #Parser/Compiler errors:
errASCantConsiderAndIgnore  =   -2720   #errASCantConsiderAndIgnore
errOSACantCreate    =   -2710   #errOSACantCreate
errOSACantGetTerminology    =   -2709   #errOSACantGetTerminology
errOSADataBlockTooLarge =   -2708   #Signaled when an intrinsic limitation is exceeded for the size of a value or data structure.
errOSAInternalTableOverflow =   -2707   #Signaled when a runtime internal data structure overflows
errOSAStackOverflow =   -2706   #Signaled when the runtime stack overflows
errOSACorruptTerminology    =   -2705   #Signaled when an application's terminology resource is not readable
errOSAAppNotHighLevelEventAware =   -2704   #Signaled when an application can't respond to AppleEvents
errOSACantLaunch    =   -2703   #Signaled when application can't be launched or when it is remote and program linking is not enabled
errOSANumericOverflow   =   -2702   #Signaled when integer or real value is too large to be represented
errOSADivideByZero  =   -2701   #Signaled when there is an attempt to divide by zero
errOSAGeneralError  =   -2700   #Signaled by user scripts or applications when no actual error code is to be returned.
noIconDataAvailableErr  =   -2582   #The necessary icon data is not available
noSuchIconErr   =   -2581   #The requested icon could not be found
invalidIconRefErr   =   -2580   #The icon ref is not valid
nrCallNotSupported  =   -2557   #This call is not available or supported on this machine
nrTransactionAborted    =   -2556   #transaction was aborted
nrExitedIteratorScope   =   -2555   #outer scope of iterator was exited
nrIterationDone =   -2554   #iteration operation is done
nrPropertyAlreadyExists =   -2553   #property already exists
nrInvalidEntryIterationOp   =   -2552   #invalid entry iteration operation
nrPathBufferTooSmall    =   -2551   #buffer for path is too small
nrPathNotFound  =   -2550   #a path component lookup failed
nrResultCodeBase    =   -2549   #nrResultCodeBase
nrOverrunErr    =   -2548   #nrOverrunErr
nrNotModifiedErr    =   -2547   #nrNotModifiedErr
nrTypeMismatchErr   =   -2546   #nrTypeMismatchErr
nrPowerSwitchAbortErr   =   -2545   #nrPowerSwitchAbortErr
nrPowerErr  =   -2544   #nrPowerErr
nrDataTruncatedErr  =   -2543   #nrDataTruncatedErr
nrNotSlotDeviceErr  =   -2542   #nrNotSlotDeviceErr
nrNameErr   =   -2541   #nrNameErr
nrNotCreatedErr =   -2540   #nrNotCreatedErr
nrNotFoundErr   =   -2539   #nrNotFoundErr
nrInvalidNodeErr    =   -2538   #nrInvalidNodeErr
nrNotEnoughMemoryErr    =   -2537   #nrNotEnoughMemoryErr
nrLockedErr =   -2536   #nrLockedErr
mmInternalError =   -2526   #mmInternalError
tsmDefaultIsNotInputMethodErr   =   -2524   #Current Input source is KCHR or uchr, not Input Method  (GetDefaultInputMethod)
tsmNoStem   =   -2523   #No stem exists for the token
tsmNoMoreTokens =   -2522   #No more tokens are available for the source text
tsmNoHandler    =   -2521   #No Callback Handler exists for callback
tsmInvalidContext   =   -2520   #Invalid TSMContext specified in call
tsmUnknownErr   =   -2519   #any other errors
tsmUnsupportedTypeErr   =   -2518   #unSupported interface type error
tsmScriptHasNoIMErr =   -2517   #script has no imput method or is using old IM
tsmInputMethodIsOldErr  =   -2516   #returned by GetDefaultInputMethod
tsmComponentAlreadyOpenErr  =   -2515   #text service already opened for the document
tsmTSNotOpenErr =   -2514   #text service is not open
tsmTSHasNoMenuErr   =   -2513   #the text service has no menu
tsmUseInputWindowErr    =   -2512   #not TSM aware because we are using input window
tsmDocumentOpenErr  =   -2511   #there are open documents
tsmTextServiceNotFoundErr   =   -2510   #no text service found
tsmCantOpenComponentErr =   -2509   #canŐt open the component
tsmNoOpenTSErr  =   -2508   #no open text service
tsmDocNotActiveErr  =   -2507   #document is NOT active
tsmTSMDocBusyErr    =   -2506   #document is still active
tsmInvalidDocIDErr  =   -2505   #invalid TSM documentation id
tsmNeverRegisteredErr   =   -2504   #app never registered error (not TSM aware)
tsmAlreadyRegisteredErr =   -2503   #want to register again error
tsmNotAnAppErr  =   -2502   #not an application error
tsmInputMethodNotFoundErr   =   -2501   #tsmInputMethodNotFoundErr
tsmUnsupScriptLanguageErr   =   -2500   #tsmUnsupScriptLanguageErr
kernelUnrecoverableErr  =   -2499   #kernelUnrecoverableErr
kernelReturnValueErr    =   -2422   #kernelReturnValueErr
kernelAlreadyFreeErr    =   -2421   #kernelAlreadyFreeErr
kernelIDErr =   -2419   #kernelIDErr
kernelExceptionErr  =   -2418   #kernelExceptionErr
kernelTerminatedErr =   -2417   #kernelTerminatedErr
kernelInUseErr  =   -2416   #kernelInUseErr
kernelTimeoutErr    =   -2415   #kernelTimeoutErr
kernelAsyncReceiveLimitErr  =   -2414   #kernelAsyncReceiveLimitErr
kernelAsyncSendLimitErr =   -2413   #kernelAsyncSendLimitErr
kernelAttributeErr  =   -2412   #kernelAttributeErr
kernelExecutionLevelErr =   -2411   #kernelExecutionLevelErr
kernelDeletePermissionErr   =   -2410   #kernelDeletePermissionErr
kernelExecutePermissionErr  =   -2409   #kernelExecutePermissionErr
kernelReadPermissionErr =   -2408   #kernelReadPermissionErr
kernelWritePermissionErr    =   -2407   #kernelWritePermissionErr
kernelObjectExistsErr   =   -2406   #kernelObjectExistsErr
kernelUnsupportedErr    =   -2405   #kernelUnsupportedErr
kernelPrivilegeErr  =   -2404   #kernelPrivilegeErr
kernelOptionsErr    =   -2403   #kernelOptionsErr
kernelCanceledErr   =   -2402   #kernelCanceledErr
kernelIncompleteErr =   -2401   #kernelIncompleteErr
badCallOrderErr =   -2209   #Usually due to a status call being called prior to being setup first
noDMAErr    =   -2208   #CanŐt do DMA digitizing (i.e. can't go to requested dest
badDepthErr =   -2207   #CanŐt digitize into this depth
notExactSizeErr =   -2206   #CanŐt do exact size requested
noMoreKeyColorsErr  =   -2205   #all key indexes in use
notExactMatrixErr   =   -2204   #warning of bad matrix, digitizer did its best
matrixErr   =   -2203   #bad matrix, digitizer did nothing
qtParamErr  =   -2202   #bad input parameter (out of range, etc)
digiUnimpErr    =   -2201   #feature unimplemented
qtXMLApplicationErr =   -2159   #qtXMLApplicationErr
qtXMLParseErr   =   -2158   #qtXMLParseErr
qtActionNotHandledErr   =   -2157   #qtActionNotHandledErr
notEnoughDataErr    =   -2149   #notEnoughDataErr
urlDataHFTPURLErr   =   -2148   #urlDataHFTPURLErr
urlDataHFTPServerDisconnectedErr    =   -2147   #urlDataHFTPServerDisconnectedErr
urlDataHFTPNoPasswordErr    =   -2146   #urlDataHFTPNoPasswordErr
urlDataHFTPNeedPasswordErr  =   -2145   #urlDataHFTPNeedPasswordErr
urlDataHFTPBadNameListErr   =   -2144   #urlDataHFTPBadNameListErr
urlDataHFTPNoNetDriverErr   =   -2143   #urlDataHFTPNoNetDriverErr
urlDataHFTPFilenameErr  =   -2142   #urlDataHFTPFilenameErr
urlDataHFTPPermissionsErr   =   -2141   #urlDataHFTPPermissionsErr
urlDataHFTPQuotaErr =   -2140   #urlDataHFTPQuotaErr
urlDataHFTPNoDirectoryErr   =   -2139   #urlDataHFTPNoDirectoryErr
urlDataHFTPDataConnectionErr    =   -2138   #urlDataHFTPDataConnectionErr
urlDataHFTPServerErr    =   -2137   #urlDataHFTPServerErr
urlDataHFTPBadPasswordErr   =   -2136   #urlDataHFTPBadPasswordErr
urlDataHFTPBadUserErr   =   -2135   #urlDataHFTPBadUserErr
urlDataHFTPShutdownErr  =   -2134   #urlDataHFTPShutdownErr
urlDataHFTPProtocolErr  =   -2133   #urlDataHFTPProtocolErr
urlDataHHTTPRedirectErr =   -2132   #urlDataHHTTPRedirectErr
urlDataHHTTPURLErr  =   -2131   #urlDataHHTTPURLErr
urlDataHHTTPNoNetDriverErr  =   -2130   #urlDataHHTTPNoNetDriverErr
urlDataHHTTPProtocolErr =   -2129   #urlDataHHTTPProtocolErr
qtNetworkAlreadyAllocatedErr    =   -2127   #qtNetworkAlreadyAllocatedErr
notAllowedToSaveMovieErr    =   -2126   #notAllowedToSaveMovieErr
fileOffsetTooBigErr =   -2125   #fileOffsetTooBigErr
ASDEntryNotFoundErr =   -2124   #ASDEntryNotFoundErr
ASDBadForkErr   =   -2123   #ASDBadForkErr
ASDBadHeaderErr =   -2122   #ASDBadHeaderErr
AAPNotFoundErr  =   -2121   #AAPNotFoundErr
AAPNotCreatedErr    =   -2120   #AAPNotCreatedErr
qfcbNotCreatedErr   =   -2119   #qfcbNotCreatedErr
qfcbNotFoundErr =   -2118   #qfcbNotFoundErr
wackBadMetaDataErr  =   -2117   #wackBadMetaDataErr
wackForkNotFoundErr =   -2116   #wackForkNotFoundErr
wackBadFileErr  =   -2115   #wackBadFileErr
unknownFormatErr    =   -2114   #unknownFormatErr
pathNotVerifiedErr  =   -2113   #pathNotVerifiedErr
noPathMappingErr    =   -2112   #noPathMappingErr
emptyPathErr    =   -2111   #emptyPathErr
pathTooLongErr  =   -2110   #pathTooLongErr
cannotBeLeafAtomErr =   -2109   #cannotBeLeafAtomErr
invalidAtomTypeErr  =   -2108   #invalidAtomTypeErr
invalidAtomContainerErr =   -2107   #invalidAtomContainerErr
invalidAtomErr  =   -2106   #invalidAtomErr
duplicateAtomTypeAndIDErr   =   -2105   #duplicateAtomTypeAndIDErr
atomIndexInvalidErr =   -2104   #atomIndexInvalidErr
atomsNotOfSameTypeErr   =   -2103   #atomsNotOfSameTypeErr
notLeafAtomErr  =   -2102   #notLeafAtomErr
cannotFindAtomErr   =   -2101   #cannotFindAtomErr
unsupportedProcessorErr =   -2097   #unsupportedProcessorErr
unsupportedOSErr    =   -2096   #unsupportedOSErr
qtmlUninitialized   =   -2095   #qtmlUninitialized
qtmlDllEntryNotFoundErr =   -2094   #Windows specific errors (when qtml is loading)
qtmlDllLoadErr  =   -2093   #Windows specific errors (when qtml is loading)
componentDllEntryNotFoundErr    =   -2092   #Windows specific errors (when component is loading)
componentDllLoadErr =   -2091   #Windows specific errors (when component is loading)
videoOutputInUseErr =   -2090   #videoOutputInUseErr
noExportProcAvailableErr    =   -2089   #noExportProcAvailableErr
tuneParseOSErr  =   -2087   #tuneParseOSErr
tunePlayerFullOSErr =   -2086   #tunePlayerFullOSErr
noteChannelNotAllocatedOSErr    =   -2085   #noteChannelNotAllocatedOSErr
illegalNoteChannelOSErr =   -2084   #illegalNoteChannelOSErr
synthesizerOSErr    =   -2083   #synthesizerOSErr
synthesizerNotRespondingOSErr   =   -2082   #synthesizerNotRespondingOSErr
midiManagerAbsentOSErr  =   -2081   #midiManagerAbsentOSErr
illegalControllerOSErr  =   -2080   #illegalControllerOSErr
illegalInstrumentOSErr  =   -2079   #illegalInstrumentOSErr
illegalKnobValueOSErr   =   -2078   #illegalKnobValueOSErr
illegalKnobOSErr    =   -2077   #illegalKnobOSErr
illegalChannelOSErr =   -2076   #illegalChannelOSErr
illegalPartOSErr    =   -2075   #illegalPartOSErr
illegalVoiceAllocationOSErr =   -2074   #illegalVoiceAllocationOSErr
cantReceiveFromSynthesizerOSErr =   -2073   #cantReceiveFromSynthesizerOSErr
cantSendToSynthesizerOSErr  =   -2072   #cantSendToSynthesizerOSErr
notImplementedMusicOSErr    =   -2071   #notImplementedMusicOSErr
internalComponentErr    =   -2070   #internalComponentErr
invalidSpriteIDErr  =   -2069   #invalidSpriteIDErr
invalidImageIndexErr    =   -2068   #invalidImageIndexErr
invalidSpriteIndexErr   =   -2067   #invalidSpriteIndexErr
gWorldsNotSameDepthAndSizeErr   =   -2066   #gWorldsNotSameDepthAndSizeErr
invalidSpritePropertyErr    =   -2065   #invalidSpritePropertyErr
invalidSpriteWorldPropertyErr   =   -2064   #invalidSpriteWorldPropertyErr
missingRequiredParameterErr =   -2063   #missingRequiredParameterErr
movieTextNotFoundErr    =   -2062   #movieTextNotFoundErr
sourceNotFoundErr   =   -2061   #sourceNotFoundErr
noSourceTreeFoundErr    =   -2060   #noSourceTreeFoundErr
samplesAlreadyInMediaErr    =   -2059   #samplesAlreadyInMediaErr
auxiliaryExportDataUnavailable  =   -2058   #auxiliaryExportDataUnavailable
unsupportedAuxiliaryImportData  =   -2057   #unsupportedAuxiliaryImportData
soundSupportNotAvailableErr =   -2056   #QT for Windows error
noSoundTrackInMovieErr  =   -2055   #QT for Windows error
noVideoTrackInMovieErr  =   -2054   #QT for Windows error
featureUnsupported  =   -2053   #featureUnsupported
couldNotUseAnExistingSample =   -2052   #couldNotUseAnExistingSample
noDefaultDataRef    =   -2051   #noDefaultDataRef
badDataRefIndex =   -2050   #badDataRefIndex
invalidDataRefContainer =   -2049   #invalidDataRefContainer
noMovieFound    =   -2048   #noMovieFound
dataNoDataRef   =   -2047   #dataNoDataRef
endOfDataReached    =   -2046   #endOfDataReached
dataAlreadyClosed   =   -2045   #dataAlreadyClosed
dataAlreadyOpenForWrite =   -2044   #dataAlreadyOpenForWrite
dataNotOpenForWrite =   -2043   #dataNotOpenForWrite
dataNotOpenForRead  =   -2042   #dataNotOpenForRead
invalidSampleDescription    =   -2041   #invalidSampleDescription
invalidChunkCache   =   -2040   #invalidChunkCache
invalidSampleDescIndex  =   -2039   #invalidSampleDescIndex
invalidChunkNum =   -2038   #invalidChunkNum
invalidSampleNum    =   -2037   #invalidSampleNum
invalidRect =   -2036   #invalidRect
cantEnableTrack =   -2035   #cantEnableTrack
internalQuickTimeError  =   -2034   #internalQuickTimeError
badEditIndex    =   -2033   #badEditIndex
timeNotInMedia  =   -2032   #timeNotInMedia
timeNotInTrack  =   -2031   #timeNotInTrack
trackNotInMovie =   -2030   #trackNotInMovie
trackIDNotFound =   -2029   #trackIDNotFound
badTrackIndex   =   -2028   #badTrackIndex
maxSizeToGrowTooSmall   =   -2027   #maxSizeToGrowTooSmall
userDataItemNotFound    =   -2026   #userDataItemNotFound
staleEditState  =   -2025   #staleEditState
nonMatchingEditState    =   -2024   #nonMatchingEditState
invalidEditState    =   -2023   #invalidEditState
cantCreateSingleForkFile    =   -2022   #happens when file already exists
wfFileNotFound  =   -2021   #wfFileNotFound
movieToolboxUninitialized   =   -2020   #movieToolboxUninitialized
progressProcAborted =   -2019   #progressProcAborted
mediaTypesDontMatch =   -2018   #mediaTypesDontMatch
badEditList =   -2017   #badEditList
cantPutPublicMovieAtom  =   -2016   #cantPutPublicMovieAtom
invalidTime =   -2015   #invalidTime
invalidDuration =   -2014   #invalidDuration
invalidHandler  =   -2013   #invalidHandler
invalidDataRef  =   -2012   #invalidDataRef
invalidSampleTable  =   -2011   #invalidSampleTable
invalidMovie    =   -2010   #invalidMovie
invalidTrack    =   -2009   #invalidTrack
invalidMedia    =   -2008   #invalidMedia
noDataHandler   =   -2007   #noDataHandler
noMediaHandler  =   -2006   #noMediaHandler
badComponentType    =   -2005   #badComponentType
cantOpenHandler =   -2004   #cantOpenHandler
cantFindHandler =   -2003   #cantFindHandler
badPublicMovieAtom  =   -2002   #badPublicMovieAtom
badImageDescription =   -2001   #badImageDescription
couldNotResolveDataRef  =   -2000   #couldNotResolveDataRef
nonDragOriginatorErr    =   -1862   #illegal attempt at originator only data
badImageErr =   -1861   #bad translucent image PixMap
badImageRgnErr  =   -1860   #bad translucent image region
noSuitableDisplaysErr   =   -1859   #no displays support translucency
unsupportedForPlatformErr   =   -1858   #call is for PowerPC only
dragNotAcceptedErr  =   -1857   #drag was not accepted by receiver
handlerNotFoundErr  =   -1856   #handler not found
duplicateHandlerErr =   -1855   #handler already exists
cantGetFlavorErr    =   -1854   #error while trying to get flavor data
duplicateFlavorErr  =   -1853   #flavor type already exists
badDragFlavorErr    =   -1852   #unknown flavor type
badDragItemErr  =   -1851   #unknown drag item reference
badDragRefErr   =   -1850   #unknown drag reference
errEndOfBody    =   -1813   #errEndOfBody
errEndOfDocument    =   -1812   #errEndOfDocument
errTopOfBody    =   -1811   #errTopOfBody
errTopOfDocument    =   -1810   #errTopOfDocument
errOffsetIsOutsideOfView    =   -1801   #errOffsetIsOutsideOfView
errOffsetInvalid    =   -1800   #errOffsetInvalid
errOSACantOpenComponent =   -1762   #Can't connect to scripting system with that ID
errOSAComponentMismatch =   -1761   #Parameters are from 2 different components
errOSADataFormatTooNew  =   -1759   #errOSADataFormatTooNew
errOSADataFormatObsolete    =   -1758   #errOSADataFormatObsolete
errOSANoSuchDialect =   -1757   #errOSANoSuchDialect
errOSASourceNotAvailable    =   -1756   #errOSASourceNotAvailable
errOSABadSelector   =   -1754   #errOSABadSelector
errOSAScriptError   =   -1753   #errOSAScriptError
errOSABadStorageType    =   -1752   #errOSABadStorageType
errOSAInvalidID =   -1751   #errOSAInvalidID
errOSASystemError   =   -1750   #errOSASystemError
errAEBufferTooSmall =   -1741   #buffer for AEFlattenDesc too small
errAEBuildSyntaxError   =   -1740   #AEBuildDesc and friends detected a syntax error
errAEDescIsNull =   -1739   #attempting to perform an invalid operation on a null descriptor
errAEStreamAlreadyConverted =   -1738   #attempt to convert a stream that has already been converted
errAEStreamBadNesting   =   -1737   #nesting violation while streaming
errAEDuplicateHandler   =   -1736   #attempt to install handler in table for identical class and id (1.1 or greater)
errAEEventFiltered  =   -1735   #event has been filtered, and should not be propogated (1.1 or greater)
errAEReceiveEscapeCurrent   =   -1734   #break out of only lowest level of AEReceive (1.1 or greater)
errAEReceiveTerminate   =   -1733   #break out of all levels of AEReceive to the topmost (1.1 or greater)
errAERecordingIsAlreadyOn   =   -1732   #available only in version 1.0.1 or greater
errAEUnknownObjectType  =   -1731   #available only in version 1.0.1 or greater
errAEEmptyListContainer =   -1730   #Attempt to pass empty list as container to accessor
errAENegativeCount  =   -1729   #CountProc returned negative value
errAENoSuchObject   =   -1728   #e.g.,: specifier asked for the 3rd, but there are only 2. Basically, this indicates a run-time resolution error.
errAENotAnObjSpec   =   -1727   #Param to AEResolve not of type 'obj '
errAEBadTestKey =   -1726   #Test is neither typeLogicalDescriptor nor typeCompDescriptor
errAENoSuchLogical  =   -1725   #Something other than AND, OR, or NOT
errAEAccessorNotFound   =   -1723   #Accessor proc matching wantClass and containerType or wildcards not found
errAEWrongNumberArgs    =   -1721   #Logical op kAENOT used with other than 1 term
errAEImpossibleRange    =   -1720   #A range like 3rd to 2nd, or 1st to all.
errAEIllegalIndex   =   -1719   #index is out of range in a put operation
errAEReplyNotArrived    =   -1718   #the contents of the reply you are accessing have not arrived yet
errAEHandlerNotFound    =   -1717   #no handler in the dispatch tables fits the parameters to AEGetEventHandler or AEGetCoercionHandler
errAEUnknownAddressType =   -1716   #the target address type is not known
errAEParamMissed    =   -1715   #a required parameter was not accessed
errAENotASpecialFunction    =   -1714   #there is no special function for/with this keyword
errAENoUserInteraction  =   -1713   #no user interaction is allowed
errAETimeout    =   -1712   #the AppleEvent timed out
errAEWaitCanceled   =   -1711   #in AESend, the user cancelled out of wait loop for reply or receipt
errAEUnknownSendMode    =   -1710   #mode wasn't NoReply, WaitReply, or QueueReply or Interaction level is unknown
errAEReplyNotValid  =   -1709   #AEResetTimer was passed an invalid reply parameter
errAEEventNotHandled    =   -1708   #the AppleEvent was not handled by any handler
errAENotAppleEvent  =   -1707   #the event is not in AppleEvent format
errAENewerVersion   =   -1706   #need newer version of the AppleEvent manager
errAEBadListItem    =   -1705   #the specified list item does not exist
errAENotAEDesc  =   -1704   #errAENotAEDesc
errAEWrongDataType  =   -1703   #errAEWrongDataType
errAECorruptData    =   -1702   #errAECorruptData
errAEDescNotFound   =   -1701   #errAEDescNotFound
errAECoercionFail   =   -1700   #bad parameter data or unable to coerce the data supplied
errFSIteratorNotSupported   =   -1424   #The iterator's flags or container are not supported by this call
errFSIteratorNotFound   =   -1423   #Passed FSIterator is not an open iterator
errFSBadIteratorFlags   =   -1422   #Flags passed to FSOpenIterator are bad
errFSForkExists =   -1421   #Named fork already exists.
errFSRefsDifferent  =   -1420   #FSCompareFSRefs; refs are for different objects
errFSBadSearchParams    =   -1419   #Something wrong with CatalogSearch searchParams
errFSBadItemCount   =   -1418   #maximumItems was zero
errFSNoMoreItems    =   -1417   #Iteration ran out of items to return
errFSBadAllocFlags  =   -1413   #Invalid bits set in allocationFlags
errFSBadPosMode =   -1412   #Newline bits set in positionMode
errFSMissingName    =   -1411   #A Unicode name parameter was NULL or nameLength parameter was zero
errFSNameTooLong    =   -1410   #File/fork name is too long to create/rename
errFSForkNotFound   =   -1409   #Named fork does not exist
errFSNotAFolder =   -1407   #Expected a folder, got a file
errFSMissingCatInfo =   -1406   #A CatalogInfo parameter was NULL
errFSBadInfoBitmap  =   -1405   #A CatalogInfoBitmap or VolumeInfoBitmap has reserved or invalid bits set
errFSBadForkRef =   -1404   #A ForkRefNum parameter was bad
errFSBadBuffer  =   -1403   #A buffer parameter was bad
errFSBadForkName    =   -1402   #Fork name parameter is bad
errFSBadFSRef   =   -1401   #FSRef parameter is bad
errFSUnknownCall    =   -1400   #selector is not recognized by this filesystem
badFCBErr   =   -1327   #FCBRecPtr is not valid
volVMBusyErr    =   -1311   #can't eject because volume is in use by VM
fsDataTooBigErr =   -1310   #file or volume is too big for system
fileBoundsErr   =   -1309   #file's EOF, offset, mark or size is too big
notARemountErr  =   -1308   #when _Mount allows only remounts and doesn't get one
badFidErr   =   -1307   #file id is dangling or doesn't match with the file number
sameFileErr =   -1306   #can't exchange a file with itself
desktopDamagedErr   =   -1305   #desktop database files are corrupted
catChangedErr   =   -1304   #the catalog has been modified
diffVolErr  =   -1303   #files on different volumes
notAFileErr =   -1302   #directory specified
fidExists   =   -1301   #file id already exists
fidNotFound =   -1300   #no file thread exists.
errRefNum   =   -1280   #bad connection refNum
errAborted  =   -1279   #control call was aborted
errState    =   -1278   #bad connection state for this operation
errOpening  =   -1277   #open connection request failed
errAttention    =   -1276   #attention message too long
errFwdReset =   -1275   #read terminated by forward reset
errDSPQueueSize =   -1274   #DSP Read/Write Queue Too small
errOpenDenied   =   -1273   #open connection request was denied
reqAborted  =   -1105   #reqAborted
noDataArea  =   -1104   #noDataArea
noSendResp  =   -1103   #noSendResp
cbNotFound  =   -1102   #cbNotFound
noRelErr    =   -1101   #noRelErr
badBuffNum  =   -1100   #badBuffNum
badATPSkt   =   -1099   #badATPSkt
tooManySkts =   -1098   #tooManySkts
tooManyReqs =   -1097   #tooManyReqs
reqFailed   =   -1096   #reqFailed
aspNoAck    =   -1075   #No ack on attention request (server err)
aspTooMany  =   -1074   #Too many clients (server error)
aspSizeErr  =   -1073   #Command block too big
aspSessClosed   =   -1072   #Session closed
aspServerBusy   =   -1071   #Server cannot open another session
aspParamErr =   -1070   #Parameter error
aspNoServers    =   -1069   #No servers at that address
aspNoMoreSess   =   -1068   #No more sessions on server
aspBufTooSmall  =   -1067   #Buffer too small
aspBadVersNum   =   -1066   #Server cannot support this ASP version
nbpNISErr   =   -1029   #Error trying to open the NIS
nbpNotFound =   -1028   #Name not found on remove
nbpDuplicate    =   -1027   #Duplicate name exists already
nbpConfDiff =   -1026   #Name confirmed at different socket
nbpNoConfirm    =   -1025   #nbpNoConfirm
nbpBuffOvr  =   -1024   #Buffer overflow in LookupName
noMaskFoundErr  =   -1000   #Icon Utilties Error
kFMFontContainerAccessErr   =   -985    #kFMFontContainerAccessErr
kFMFontTableAccessErr   =   -984    #kFMFontTableAccessErr
kFMIterationScopeModifiedErr    =   -983    #kFMIterationScopeModifiedErr
kFMInvalidFontErr   =   -982    #kFMInvalidFontErr
kFMInvalidFontFamilyErr =   -981    #kFMInvalidFontFamilyErr
kFMIterationCompleted   =   -980    #kFMIterationCompleted
guestNotAllowedErr  =   -932    #destination port requires authentication
badLocNameErr   =   -931    #location name malformed
badServiceMethodErr =   -930    #illegal service type, or not supported
noUserRecErr    =   -928    #Invalid user reference number
authFailErr =   -927    #unable to authenticate user at destination
noInformErr =   -926    #PPCStart failed because destination did not have inform pending
networkErr  =   -925    #An error has occurred in the network, not too likely
noUserRefErr    =   -924    #unable to create a new userRefNum
notLoggedInErr  =   -923    #The default userRefNum does not yet exist
noDefaultUserErr    =   -922    #user hasn't typed in owners name in Network Setup Control Pannel
badPortNameErr  =   -919    #PPCPortRec malformed
sessClosedErr   =   -917    #session was closed
portClosedErr   =   -916    #port was closed
noResponseErr   =   -915    #unable to contact destination
noToolboxNameErr    =   -914    #A system resource is missing, not too likely
noMachineNameErr    =   -913    #user hasn't named his Macintosh in the Network Setup Control Panel
userRejectErr   =   -912    #Destination rejected the session request
noUserNameErr   =   -911    #user name unknown on destination machine
portNameExistsErr   =   -910    #port is already open (perhaps in another app)
badReqErr   =   -909    #bad parameter or invalid state for operation
noSessionErr    =   -908    #Invalid session reference number
sessTableErr    =   -907    #Out of session tables, try again later
destPortErr =   -906    #Port does not exist at destination
localOnlyErr    =   -905    #Network activity is currently disabled
noGlobalsErr    =   -904    #The system is hosed, better re-boot
noPortErr   =   -903    #Unable to open port or bad portRefNum.  If you're calling
nameTypeErr =   -902    #Invalid or inappropriate locationKindSelector in locationName
notInitErr  =   -900    #PPCToolBox not initialized
notAppropriateForClassic    =   -877    #This application won't or shouldn't run on Classic (Problem 2481058).
appVersionTooOld    =   -876    #The application's creator and version are incompatible with the current version of Mac OS.
wrongApplicationPlatform    =   -875    #The application could not launch because the required platform is not available
hmCloseViewActive   =   -863    #Returned from HMRemoveBalloon if CloseView was active
hmNoBalloonUp   =   -862    #Returned from HMRemoveBalloon if no balloon was visible when call was made
hmOperationUnsupported  =   -861    #Returned from HMShowBalloon call if bad method passed to routine
hmUnknownHelpType   =   -859    #Returned if help msg record contained a bad type
hmWrongVersion  =   -858    #Returned if help mgr resource was the wrong version
hmSkippedBalloon    =   -857    #Returned from calls if helpmsg specified a skip balloon
hmHelpManagerNotInited  =   -855    #Returned from HMGetHelpMenuHandle if help menu not setup
hmSameAsLastBalloon =   -854    #Returned from HMShowMenuBalloon if menu & item is same as last time
hmBalloonAborted    =   -853    #Returned if mouse was moving or mouse wasn't in window port rect
hmHelpDisabled  =   -850    #Show Balloons mode was off, call to routine ignored
rcDBPackNotInited   =   -813    #attempt to call other routine before InitDBPack
rcDBWrongVersion    =   -812    #incompatible versions
rcDBNoHandler   =   -811    #no app handler for specified data type
rcDBBadAsyncPB  =   -810    #tried to kill a bad pb
rcDBAsyncNotSupp    =   -809    #ddev does not support async calls
rcDBBadDDEV =   -808    #bad ddev specified on DBInit
rcDBBadSessNum  =   -807    #bad session number for DBGetConnInfo
rcDBBadSessID   =   -806    #rcDBBadSessID
rcDBExec    =   -805    #rcDBExec
rcDBBreak   =   -804    #rcDBBreak
rcDBBadType =   -803    #rcDBBadType
rcDBError   =   -802    #rcDBError
rcDBValue   =   -801    #rcDBValue
rcDBNull    =   -800    #rcDBNull
icTooManyProfilesErr    =   -677    #too many profiles in database
icProfileNotFoundErr    =   -676    #profile not found
icConfigInappropriateErr    =   -675    #incorrect manufacturer code
icConfigNotFoundErr =   -674    #no internet configuration was found
icNoURLErr  =   -673    #no URL found
icNothingToOverrideErr  =   -672    #no component for the override component to capture
icNoMoreWritersErr  =   -671    #you cannot begin a write session because someone else is already doing it
icTruncatedErr  =   -670    #more data was present than was returned
icInternalErr   =   -669    #Internet Config internal error
icPrefDataErr   =   -668    #problem with preference data
icPermErr   =   -667    #cannot set preference
icPrefNotFoundErr   =   -666    #Internet preference not found
vmInvalidOwningProcessErr   =   -648    #current process does not own the BackingFileID or FileViewID
vmAddressNotInFileViewErr   =   -647    #address is not in a FileView
vmNoMoreFileViewsErr    =   -646    #no more FileViews were found
vmFileViewAccessErr =   -645    #requested FileViewAccess cannot be obtained
vmInvalidFileViewIDErr  =   -644    #invalid FileViewID
vmNoMoreBackingFilesErr =   -643    #no more BackingFiles were found
vmBusyBackingFileErr    =   -642    #open views found on BackingFile
vmMappingPrivilegesErr  =   -641    #requested MappingPrivileges cannot be obtained
vmInvalidBackingFileIDErr   =   -640    #invalid BackingFileID
noMMUErr    =   -626    #no MMU present
cannotDeferErr  =   -625    #unable to defer additional functions
interruptsMaskedErr =   -624    #donŐt call with interrupts masked
notLockedErr    =   -623    #specified range of memory is not locked
cannotMakeContiguousErr =   -622    #cannot make specified range contiguous
notHeldErr  =   -621    #specified range of memory is not held
notEnoughMemoryErr  =   -620    #insufficient physical memory
threadProtocolErr   =   -619    #threadProtocolErr
threadNotFoundErr   =   -618    #threadNotFoundErr
threadTooManyReqsErr    =   -617    #threadTooManyReqsErr
noUserInteractionAllowed    =   -610    #no user interaction allowed
connectionInvalid   =   -609    #connectionInvalid
noOutstandingHLE    =   -608    #noOutstandingHLE
bufferIsSmall   =   -607    #error returns from Post and Accept
appIsDaemon =   -606    #app is BG-only, and launch flags disallow this
appMemFullErr   =   -605    #application SIZE not big enough for launch
hardwareConfigErr   =   -604    #hardware configuration not correct for call
protocolErr =   -603    #app made module calls in improper order
appModeErr  =   -602    #memory mode is 32-bit, but app not 32-bit clean
memFragErr  =   -601    #not enough room to launch app w/special requirements
procNotFound    =   -600    #no eligible process with specified descriptor
driverHardwareGoneErr   =   -503    #disk driver's hardware was disconnected
hwParamErr  =   -502    #bad selector for _HWPriv
teScrapSizeErr  =   -501    #scrap item too big for text edit record
rgnTooBigErr    =   -500    #rgnTooBigErr
exUserBreak =   -492    #user debugger break; execute debugger commands on stack
strUserBreak    =   -491    #user debugger break; display string on stack
userBreak   =   -490    #user debugger break
notThePublisherWrn  =   -463    #not the first registered publisher for that container
containerAlreadyOpenWrn =   -462    #container already opened by this section
containerNotFoundWrn    =   -461    #could not find editionContainer at this time
multiplePublisherWrn    =   -460    #A Publisher is already registered for that container
badSubPartErr   =   -454    #can not use sub parts in this release
badEditionFileErr   =   -453    #edition file is corrupt
notRegisteredSectionErr =   -452    #not a registered SectionRecord
badSectionErr   =   -451    #not a valid SectionRecord
editionMgrInitErr   =   -450    #edition manager not inited by this app
fsmUnknownFSMMessageErr =   -438    #unknown message passed to FSM
fsmNoAlternateStackErr  =   -437    #no alternate stack for HFS CI
fsmBadFSDVersionErr =   -436    #FSM version incompatible with FSD
fsmDuplicateFSIDErr =   -435    #FSID already exists on InstallFS
fsmBadFSDLenErr =   -434    #FSD size incompatible with current FSM vers
fsmBadFFSNameErr    =   -433    #Name length not 1 <= length <= 31
fsmBusyFFSErr   =   -432    #File system is busy, cannot be removed
fsmFFSNotFoundErr   =   -431    #Foreign File system does not exist - new Pack2 could return this error too
btKeyAttrErr    =   -417    #There is no such a key attribute.
btKeyLenErr =   -416    #Maximum key length is too long or equal to zero.
btRecNotFnd =   -415    #Record cannot be found.
btDupRecErr =   -414    #Record already exists.
btNoSpace   =   -413    #Can't allocate disk space.
notBTree    =   -410    #The file is not a dictionary.
gcrOnMFMErr =   -400    #gcr format on high density media error
slotNumErr  =   -360    #invalid slot # error
smRecNotFnd =   -351    #Record not found in the SRT.
smSRTOvrFlErr   =   -350    #SRT over flow.
smNoGoodOpens   =   -349    #No opens were successfull in the loop.
smOffsetErr =   -348    #Offset was too big (temporary error
smByteLanesErr  =   -347    #NumByteLanes was determined to be zero.
smBadsPtrErr    =   -346    #Bad pointer was passed to sCalcsPointer
smsGetDrvrErr   =   -345    #Error occurred during _sGetDriver.
smNoMoresRsrcs  =   -344    #No more sResources
smDisDrvrNamErr =   -343    #Error occurred during _sDisDrvrName.
smGetDrvrNamErr =   -342    #Error occurred during _sGetDrvrName.
smCkStatusErr   =   -341    #Status of slot = fail.
smBlkMoveErr    =   -340    #_BlockMove error
smNewPErr   =   -339    #_NewPtr error
smSelOOBErr =   -338    #Selector out of bounds error
smSlotOOBErr    =   -337    #Slot out of bounds error
smNilsBlockErr  =   -336    #Nil sBlock error (Dont allocate and try to use a nil sBlock)
smsPointerNil   =   -335    #LPointer is nil From sOffsetData. If this error occurs; check sInfo rec for more information.
smCPUErr    =   -334    #Code revision is wrong
smCodeRevErr    =   -333    #Code revision is wrong
smReservedErr   =   -332    #Reserved field not zero
smBadsList  =   -331    #Bad sList: Id1 < Id2 < Id3 ...format is not followed.
smBadRefId  =   -330    #Reference Id not found in List
smBusErrTO  =   -320    #BusError time out.
smBadBoardId    =   -319    #BoardId was wrong; re-init the PRAM record.
smReservedSlot  =   -318    #slot is reserved, VM should not use this address space.
smInitTblVErr   =   -317    #An error occurred while trying to initialize the Slot Resource Table.
smInitStatVErr  =   -316    #The InitStatusV field was negative after primary or secondary init.
smNoBoardId =   -315    #No Board Id.
smGetPRErr  =   -314    #Error occurred during _sGetPRAMRec (See SIMStatus).
smNoBoardSRsrc  =   -313    #No Board sResource.
smDisposePErr   =   -312    #_DisposePointer error
smFHBlkDispErr  =   -311    #Error occurred during _sDisposePtr (Dispose of FHeader block).
smFHBlockRdErr  =   -310    #Error occurred during _sGetFHeader.
smBLFieldBad    =   -309    #ByteLanes field was bad.
smUnExBusErr    =   -308    #Unexpected BusError
smResrvErr  =   -307    #Fatal reserved error. Reserved field != 0.
smNosInfoArray  =   -306    #No sInfoArray. Memory Mgr error.
smDisabledSlot  =   -305    #This slot is disabled (-305 use to be smLWTstBad)
smNoDir =   -304    #Directory offset is Nil
smRevisionErr   =   -303    #Wrong revison level
smFormatErr =   -302    #FHeader Format is not Apple's
smCRCFail   =   -301    #CRC check failed for declaration data
smEmptySlot =   -300    #No card in slot
nmTypErr    =   -299    #Notification Manager:wrong queue type
smPriInitErr    =   -293    #Error; Cards could not be initialized.
smPRAMInitErr   =   -292    #Error; Slot Resource Table could not be initialized.
smSRTInitErr    =   -291    #Error; Slot Resource Table could not be initialized.
smSDMInitErr    =   -290    #Error; SDM could not be initialized.
midiInvalidCmdErr   =   -261    #command not supported for port type
midiDupIDErr    =   -260    #duplicate client ID
midiNameLenErr  =   -259    #name supplied is longer than 31 characters
midiWriteErr    =   -258    #MIDIWritePacket couldn't write to all connected ports
midiNoConErr    =   -257    #no connection exists between specified ports
midiVConnectRmvd    =   -256    #pending virtual connection removed
midiVConnectMade    =   -255    #pending virtual connection resolved
midiVConnectErr =   -254    #pending virtual connection created
midiTooManyConsErr  =   -253    #too many connections made
midiTooManyPortsErr =   -252    #too many ports already installed in the system
midiNoPortErr   =   -251    #no port with that ID found
midiNoClientErr =   -250    #no client with that ID found
badInputText    =   -247    #badInputText
badDictFormat   =   -246    #badDictFormat
incompatibleVoice   =   -245    #incompatibleVoice
voiceNotFound   =   -244    #voiceNotFound
bufTooSmall =   -243    #bufTooSmall
synthNotReady   =   -242    #synthNotReady
synthOpenFailed =   -241    #synthOpenFailed
noSynthFound    =   -240    #noSynthFound
siUnknownQuality    =   -232    #invalid quality selector (returned by driver)
siUnknownInfoType   =   -231    #invalid info type selector (returned by driver)
siInputDeviceErr    =   -230    #input device hardware failure
siBadRefNum =   -229    #invalid input device reference number
siBadDeviceName =   -228    #input device could not be opened
siDeviceBusyErr =   -227    #input device already in use
siInvalidSampleSize =   -226    #invalid sample size
siInvalidSampleRate =   -225    #invalid sample rate
siHardDriveTooSlow  =   -224    #hard drive too slow to record to disk
siInvalidCompression    =   -223    #invalid compression type
siNoBufferSpecified =   -222    #returned by synchronous SPBRecord if nil buffer passed
siBadSoundInDevice  =   -221    #invalid index passed to SoundInGetIndexedDevice
siNoSoundInHardware =   -220    #no Sound Input hardware
siVBRCompressionNotSupported    =   -213    #vbr audio compression not supported for this operation
noMoreRealTime  =   -212    #not enough CPU cycles left to add another task
channelNotBusy  =   -211    #channelNotBusy
buffersTooSmall =   -210    #can not operate in the memory allowed
channelBusy =   -209    #the Channel is being used for a PFD already
badFileFormat   =   -208    #was not type AIFF or was of bad format,corrupt
notEnoughBufferSpace    =   -207    #could not allocate enough memory
badFormat   =   -206    #Sound Manager Error Returns
badChannel  =   -205    #Sound Manager Error Returns
resProblem  =   -204    #Sound Manager Error Returns
queueFull   =   -203    #Sound Manager Error Returns
notEnoughHardwareErr    =   -201    #Sound Manager Error Returns
noHardwareErr   =   -200    #Sound Manager Error Returns
mapReadErr  =   -199    #map inconsistent with operation
resAttrErr  =   -198    #attribute inconsistent with operation
rmvRefFailed    =   -197    #RmveReference failed
rmvResFailed    =   -196    #RmveResource failed
addRefFailed    =   -195    #AddReference failed
addResFailed    =   -194    #AddResource failed
resFNotFound    =   -193    #Resource file not found
resNotFound =   -192    #Resource not found
inputOutOfBounds    =   -190    #Offset of Count out of bounds
writingPastEnd  =   -189    #Writing past end of file
resourceInMemory    =   -188    #Resource already in memory
CantDecompress  =   -186    #resource bent ("the bends") - can't decompress a compressed resource
badExtResource  =   -185    #extended resource has a bad format.
cmNoCurrentProfile  =   -182    #Responder error
cmUnsupportedDataType   =   -181    #Responder error
cmCantDeleteProfile =   -180    #Responder error
cmCantXYZ   =   -179    #CMM cant handle XYZ space
cmCantConcatenateError  =   -178    #Profile can't be concatenated
cmProfilesIdentical =   -177    #Profiles the same
cmProfileNotFound   =   -176    #Responder error
cmMethodNotFound    =   -175    #CMM not present
cmMethodError   =   -171    #cmMethodError
cmProfileError  =   -170    #cmProfileError
cDepthErr   =   -157    #invalid pixel depth
cResErr =   -156    #invalid resolution for MakeITable
cDevErr =   -155    #invalid type of graphics device
cProtectErr =   -154    #colorTable entry protection violation
cRangeErr   =   -153    #range error on colorTable request
cNoMemErr   =   -152    #failed to allocate memory for structure
cTempMemErr =   -151    #failed to allocate memory for temporary structures
cMatchErr   =   -150    #Color2Index failed to find an index
insufficientStackErr    =   -149    #insufficientStackErr
pixMapTooDeepErr    =   -148    #pixMapTooDeepErr
rgnOverflowErr  =   -147    #rgnOverflowErr
noMemForPictPlaybackErr =   -145    #noMemForPictPlaybackErr
userCanceledErr =   -128    #userCanceledErr
hMenuFindErr    =   -127    #could not find HMenu's parent in MenuKey (wrong error code - obsolete)
mBarNFnd    =   -126    #system error code for MBDF not found
updPixMemErr    =   -125    #insufficient memory to update a pixmap
volGoneErr  =   -124    #Server volume has been disconnected.
wrgVolTypErr    =   -123    #Wrong volume type error [operation not supported for MFS]
badMovErr   =   -122    #Move into offspring error
tmwdoErr    =   -121    #No free WDCB available
dirNFErr    =   -120    #Directory not found
memLockedErr    =   -117    #trying to move a locked block (MoveHHi)
memSCErr    =   -116    #Size Check failed
memBCErr    =   -115    #Block Check failed
memPCErr    =   -114    #Pointer Check failed
memAZErr    =   -113    #Address in zone check failed
memPurErr   =   -112    #trying to purge a locked or non-purgeable block
memWZErr    =   -111    #WhichZone failed (applied to free block)
memAdrErr   =   -110    #address was odd; or out of range
nilHandleErr    =   -109    #Master Pointer was NIL in HandleZone or other
memFullErr  =   -108    #Not enough room in heap zone
noTypeErr   =   -102    #No object of that type in scrap
noScrapErr  =   -100    #No scrap exists error
memROZWarn  =   -99 #soft error in ROZ
portNotCf   =   -98 #driver Open error code (parameter RAM not configured for this connection)
portInUse   =   -97 #driver Open error code (port is in use)
portNotPwr  =   -96 #serial port not currently powered
excessCollsns   =   -95 #excessive collisions on write
lapProtErr  =   -94 #error in attaching/detaching protocol
noBridgeErr =   -93 #no network bridge for non-local send
eLenErr =   -92 #Length error ddpLenErr
eMultiErr   =   -91 #Multicast address error ddpSktErr
breakRecd   =   -90 #Break received (SCC)
rcvrErr =   -89 #SCC receiver error (framing; parity; OR)
prInitErr   =   -88 #InitUtil found the parameter ram uninitialized
prWrErr =   -87 #parameter ram written didn't read-verify
clkWrErr    =   -86 #time written did not verify
clkRdErr    =   -85 #unable to read same clock value twice
verErr  =   -84 #track failed to verify
fmt2Err =   -83 #can't get enough sync
fmt1Err =   -82 #can't find sector 0 after track format
sectNFErr   =   -81 #sector number never found on a track
seekErr =   -80 #track number wrong on address mark
spdAdjErr   =   -79 #unable to correctly adjust disk speed
twoSideErr  =   -78 #tried to read 2nd side on a 1-sided drive
initIWMErr  =   -77 #unable to initialize IWM
tk0BadErr   =   -76 #track 0 detect doesn't change
cantStepErr =   -75 #step handshake failed
wrUnderrun  =   -74 #write underrun occurred
badDBtSlp   =   -73 #bad data mark bit slip nibbles
badDCksum   =   -72 #bad data mark checksum
noDtaMkErr  =   -71 #couldn't find a data mark header
badBtSlpErr =   -70 #bad addr mark bit slip nibbles
badCksmErr  =   -69 #addr mark checksum didn't check
dataVerErr  =   -68 #read verify compare failed
noAdrMkErr  =   -67 #couldn't find valid addr mark
noNybErr    =   -66 #couldn't find 5 nybbles in 200 tries
offLinErr   =   -65 #r/w requested for an off-line drive
fontDecError    =   -64 #error during font declaration
wrPermErr   =   -61 #write permissions error
badMDBErr   =   -60 #bad master directory block
fsRnErr =   -59 #file system internal error:during rename the old entry was deleted but could not be restored.
extFSErr    =   -58 #volume in question belongs to an external fs
noMacDskErr =   -57 #not a mac diskette (sig bytes are wrong)
nsDrvErr    =   -56 #no such drive (tried to mount a bad drive num)
volOnLinErr =   -55 #drive volume already on-line at MountVol
permErr =   -54 #permissions error (on file open)
volOffLinErr    =   -53 #volume not on line error (was Ejected)
gfpErr  =   -52 #get file position error
rfNumErr    =   -51 #refnum error
paramErr    =   -50 #error in user parameter list
opWrErr =   -49 #file already open with with write permission
dupFNErr    =   -48 #duplicate filename (rename)
fBsyErr =   -47 #File is busy (delete)
vLckdErr    =   -46 #volume is locked
fLckdErr    =   -45 #file is locked
wPrErr  =   -44 #diskette is write protected.
fnfErr  =   -43 #File not found
tmfoErr =   -42 #too many files open
mFulErr =   -41 #memory full (open) or file won't fit (load)
posErr  =   -40 #tried to position to before start of file (r/w)
eofErr  =   -39 #End of file
fnOpnErr    =   -38 #File not open
bdNamErr    =   -37 #there may be no bad names in the final system!
ioErr   =   -36 #I/O error (bummers)
nsvErr  =   -35 #no such volume
dskFulErr   =   -34 #disk full
dirFulErr   =   -33 #Directory full
dceExtErr   =   -30 #dce extension error
unitTblFullErr  =   -29 #unit table has no more entries
notOpenErr  =   -28 #Couldn't rd/wr/ctl/sts cause driver not opened
iIOAbortErr =   -27 #IO abort error (Printing Manager)
dInstErr    =   -26 #DrvrInstall couldn't find driver in resources
dRemovErr   =   -25 #tried to remove an open driver
closErr =   -24 #I/O System Errors
openErr =   -23 #I/O System Errors
unitEmptyErr    =   -22 #I/O System Errors
badUnitErr  =   -21 #I/O System Errors
writErr =   -20 #I/O System Errors
readErr =   -19 #I/O System Errors
statusErr   =   -18 #I/O System Errors
controlErr  =   -17 #I/O System Errors
dsExtensionsDisabled    =   -13 #say –Extensions Disabled”
dsHD20Installed =   -12 #say –HD20 Startup”
dsDisassemblerInstalled =   -11 #say –Disassembler Installed”
dsMacsBugInstalled  =   -10 #say –MacsBug Installed”
seNoDB  =   -8  #no debugger installed to handle debugger command
SlpTypeErr  =   -5  #invalid queue element
unimpErr    =   -4  #unimplemented core routine
corErr  =   -3  #core routine number out of range
dsNoExtsDisassembler    =   -2  #not a SysErr, just a placeholder
qErr    =   -1  #queue element not found during deletion
tsmComponentNoErr   =   0   #component result = no error
EPERM   =   1   #Operation not permitted
ENOENT  =   2   #No such file or directory
ESRCH   =   3   #No such process
EINTR   =   4   #Interrupted system call
EIO =   5   #Input/output error
ENXIO   =   6   #Device not configured
E2BIG   =   7   #Argument list too long
ENOEXEC =   8   #Exec format error
EBADF   =   9   #Bad file descriptor
ECHILD  =   10  #No child processes
EDEADLK =   11  #Resource deadlock avoided
ENOMEM  =   12  #Cannot allocate memory
EACCES  =   13  #Permission denied
EFAULT  =   14  #Bad address
ECANCELED   =   15  #Operation cancelled
EBUSY   =   16  #Device busy
EEXIST  =   17  #File exists
EXDEV   =   18  #Cross-device link
ENODEV  =   19  #Operation not supported by device
ENOTDIR =   20  #Not a directory
EISDIR  =   21  #Is a directory
EINVAL  =   22  #Invalid argument
ENFILE  =   23  #Too many open files in system
EMFILE  =   24  #Too many open files
ENOTTY  =   25  #Inappropriate ioctl for device
ESIGPARM    =   26  #Signal error
EFBIG   =   27  #File too large
ENOSPC  =   28  #No space left on device
ESPIPE  =   29  #Illegal seek
EROFS   =   30  #Read-only file system
EMLINK  =   31  #Too many links
EPIPE   =   32  #Broken pipe
EDOM    =   33  #Numerical argument out of domain
ERANGE  =   34  #Result too large
EAGAIN  =   35  #Resource temporarily unavailable
EINPROGRESS =   36  #Operation now in progress
EALREADY    =   37  #Operation already in progress
ENOTSOCK    =   38  #Socket operation on non-socket
EDESTADDRREQ    =   39  #Destination address required
EMSGSIZE    =   40  #Message too long
EPROTOTYPE  =   41  #Protocol wrong type for socket
ENOPROTOOPT =   42  #Protocol not available
EPROTONOSUPPORT =   43  #Protocol not supported
ESOCKTNOSUPPORT =   44  #Socket type not supported
EOPNOTSUPP  =   45  #Operation not supported
EPFNOSUPPORT    =   46  #Protocol family not supported
EAFNOSUPPORT    =   47  #Address family not supported by protocol family
EADDRINUSE  =   48  #Address already in use
EADDRNOTAVAIL   =   49  #Can't assign requested address
ENETDOWN    =   50  #Network is down
ENETUNREACH =   51  #Network is unreachable
ENETRESET   =   52  #Network dropped connection on reset
ECONNABORTED    =   53  #Software caused connection abort
ECONNRESET  =   54  #Connection reset by peer
ENOBUFS =   55  #No buffer space available
EISCONN =   56  #Socket is already connected
ENOTCONN    =   57  #Socket is not connected
ESHUTDOWN   =   58  #Can't send after socket shutdown
ETOOMANYREFS    =   59  #Too many references: can't splice
ETIMEDOUT   =   60  #Operation timed out
ECONNREFUSED    =   61  #Connection refused
ELOOP   =   62  #Too many levels of symbolic links
ENAMETOOLONG    =   63  #File name too long
EHOSTDOWN   =   64  #Host is down
EHOSTUNREACH    =   65  #No route to host
ENOTEMPTY   =   66  #Directory not empty
ELOOK   =   67  #Internal mapping for kOTLookErr, don't return to client
ENOLCK  =   77  #No locks available
ENOSYS  =   78  #Function not implemented
EILSEQ  =   88  #Wide character encoding error
EUNKNOWN    =   99  #Unknown error



"""
Package generated from /System/Library/CoreServices/Finder.app
"""

from warnings import warnpy3k
warnpy3k("In 3.x, the Finder package is removed.", stacklevel=2)

import aetools
Error = aetools.Error
import Standard_Suite
import Legacy_suite
import Containers_and_folders
import Files
import Finder_Basics
import Finder_items
import Window_classes
import Type_Definitions
import Enumerations


_code_to_module = {
    'CoRe' : Standard_Suite,
    'fleg' : Legacy_suite,
    'fndr' : Containers_and_folders,
    'fndr' : Files,
    'fndr' : Finder_Basics,
    'fndr' : Finder_items,
    'fndr' : Window_classes,
    'tpdf' : Type_Definitions,
    'tpnm' : Enumerations,
}



_code_to_fullname = {
    'CoRe' : ('Finder.Standard_Suite', 'Standard_Suite'),
    'fleg' : ('Finder.Legacy_suite', 'Legacy_suite'),
    'fndr' : ('Finder.Containers_and_folders', 'Containers_and_folders'),
    'fndr' : ('Finder.Files', 'Files'),
    'fndr' : ('Finder.Finder_Basics', 'Finder_Basics'),
    'fndr' : ('Finder.Finder_items', 'Finder_items'),
    'fndr' : ('Finder.Window_classes', 'Window_classes'),
    'tpdf' : ('Finder.Type_Definitions', 'Type_Definitions'),
    'tpnm' : ('Finder.Enumerations', 'Enumerations'),
}

from Standard_Suite import *
from Legacy_suite import *
from Containers_and_folders import *
from Files import *
from Finder_Basics import *
from Finder_items import *
from Window_classes import *
from Type_Definitions import *
from Enumerations import *

def getbaseclasses(v):
    if not getattr(v, '_propdict', None):
        v._propdict = {}
        v._elemdict = {}
        for superclassname in getattr(v, '_superclassnames', []):
            superclass = eval(superclassname)
            getbaseclasses(superclass)
            v._propdict.update(getattr(superclass, '_propdict', {}))
            v._elemdict.update(getattr(superclass, '_elemdict', {}))
        v._propdict.update(getattr(v, '_privpropdict', {}))
        v._elemdict.update(getattr(v, '_privelemdict', {}))

import StdSuites

#
# Set property and element dictionaries now that all classes have been defined
#
getbaseclasses(StdSuites.Type_Names_Suite.small_integer)
getbaseclasses(StdSuites.Type_Names_Suite.system_dictionary)
getbaseclasses(StdSuites.Type_Names_Suite.color_table)
getbaseclasses(StdSuites.Type_Names_Suite.fixed_point)
getbaseclasses(StdSuites.Type_Names_Suite.string)
getbaseclasses(StdSuites.Type_Names_Suite.type_element_info)
getbaseclasses(StdSuites.Type_Names_Suite.machine_location)
getbaseclasses(StdSuites.Type_Names_Suite.PostScript_picture)
getbaseclasses(StdSuites.Type_Names_Suite.type_property_info)
getbaseclasses(StdSuites.Type_Names_Suite.menu_item)
getbaseclasses(StdSuites.Type_Names_Suite.scrap_styles)
getbaseclasses(StdSuites.Type_Names_Suite.fixed_rectangle)
getbaseclasses(StdSuites.Type_Names_Suite.null)
getbaseclasses(StdSuites.Type_Names_Suite.type_event_info)
getbaseclasses(StdSuites.Type_Names_Suite.rotation)
getbaseclasses(StdSuites.Type_Names_Suite.long_fixed_rectangle)
getbaseclasses(StdSuites.Type_Names_Suite.long_point)
getbaseclasses(StdSuites.Type_Names_Suite.target_id)
getbaseclasses(StdSuites.Type_Names_Suite.type_suite_info)
getbaseclasses(StdSuites.Type_Names_Suite.type_parameter_info)
getbaseclasses(StdSuites.Type_Names_Suite.long_fixed_point)
getbaseclasses(StdSuites.Type_Names_Suite.bounding_rectangle)
getbaseclasses(StdSuites.Type_Names_Suite.TIFF_picture)
getbaseclasses(StdSuites.Type_Names_Suite.long_fixed)
getbaseclasses(StdSuites.Type_Names_Suite.version)
getbaseclasses(StdSuites.Type_Names_Suite.RGB16_color)
getbaseclasses(StdSuites.Type_Names_Suite.double_integer)
getbaseclasses(StdSuites.Type_Names_Suite.location_reference)
getbaseclasses(StdSuites.Type_Names_Suite.point)
getbaseclasses(StdSuites.Type_Names_Suite.application_dictionary)
getbaseclasses(StdSuites.Type_Names_Suite.unsigned_integer)
getbaseclasses(StdSuites.Type_Names_Suite.menu)
getbaseclasses(StdSuites.Type_Names_Suite.small_real)
getbaseclasses(StdSuites.Type_Names_Suite.fixed)
getbaseclasses(StdSuites.Type_Names_Suite.type_class_info)
getbaseclasses(StdSuites.Type_Names_Suite.RGB96_color)
getbaseclasses(StdSuites.Type_Names_Suite.dash_style)
getbaseclasses(StdSuites.Type_Names_Suite.pixel_map_record)
getbaseclasses(StdSuites.Type_Names_Suite.extended_real)
getbaseclasses(StdSuites.Type_Names_Suite.long_rectangle)
getbaseclasses(process)
getbaseclasses(application_process)
getbaseclasses(desk_accessory_process)
getbaseclasses(application)
getbaseclasses(trash_2d_object)
getbaseclasses(desktop_2d_object)
getbaseclasses(container)
getbaseclasses(folder)
getbaseclasses(disk)
getbaseclasses(application)
getbaseclasses(alias_file)
getbaseclasses(package)
getbaseclasses(file)
getbaseclasses(application_file)
getbaseclasses(internet_location_file)
getbaseclasses(document_file)
getbaseclasses(clipping)
getbaseclasses(preferences_window)
getbaseclasses(Finder_window)
getbaseclasses(window)
getbaseclasses(clipping_window)
getbaseclasses(information_window)
getbaseclasses(item)
getbaseclasses(icon_view_options)
getbaseclasses(preferences)
getbaseclasses(alias_list)
getbaseclasses(icon_family)
getbaseclasses(label)
getbaseclasses(column)
getbaseclasses(list_view_options)

#
# Indices of types declared in this module
#
_classdeclarations = {
    'shor' : StdSuites.Type_Names_Suite.small_integer,
    'aeut' : StdSuites.Type_Names_Suite.system_dictionary,
    'clrt' : StdSuites.Type_Names_Suite.color_table,
    'fpnt' : StdSuites.Type_Names_Suite.fixed_point,
    'TEXT' : StdSuites.Type_Names_Suite.string,
    'elin' : StdSuites.Type_Names_Suite.type_element_info,
    'mLoc' : StdSuites.Type_Names_Suite.machine_location,
    'EPS ' : StdSuites.Type_Names_Suite.PostScript_picture,
    'pinf' : StdSuites.Type_Names_Suite.type_property_info,
    'cmen' : StdSuites.Type_Names_Suite.menu_item,
    'styl' : StdSuites.Type_Names_Suite.scrap_styles,
    'frct' : StdSuites.Type_Names_Suite.fixed_rectangle,
    'null' : StdSuites.Type_Names_Suite.null,
    'evin' : StdSuites.Type_Names_Suite.type_event_info,
    'trot' : StdSuites.Type_Names_Suite.rotation,
    'lfrc' : StdSuites.Type_Names_Suite.long_fixed_rectangle,
    'lpnt' : StdSuites.Type_Names_Suite.long_point,
    'targ' : StdSuites.Type_Names_Suite.target_id,
    'suin' : StdSuites.Type_Names_Suite.type_suite_info,
    'pmin' : StdSuites.Type_Names_Suite.type_parameter_info,
    'lfpt' : StdSuites.Type_Names_Suite.long_fixed_point,
    'qdrt' : StdSuites.Type_Names_Suite.bounding_rectangle,
    'TIFF' : StdSuites.Type_Names_Suite.TIFF_picture,
    'lfxd' : StdSuites.Type_Names_Suite.long_fixed,
    'vers' : StdSuites.Type_Names_Suite.version,
    'tr16' : StdSuites.Type_Names_Suite.RGB16_color,
    'comp' : StdSuites.Type_Names_Suite.double_integer,
    'insl' : StdSuites.Type_Names_Suite.location_reference,
    'QDpt' : StdSuites.Type_Names_Suite.point,
    'aete' : StdSuites.Type_Names_Suite.application_dictionary,
    'magn' : StdSuites.Type_Names_Suite.unsigned_integer,
    'cmnu' : StdSuites.Type_Names_Suite.menu,
    'sing' : StdSuites.Type_Names_Suite.small_real,
    'fixd' : StdSuites.Type_Names_Suite.fixed,
    'gcli' : StdSuites.Type_Names_Suite.type_class_info,
    'tr96' : StdSuites.Type_Names_Suite.RGB96_color,
    'tdas' : StdSuites.Type_Names_Suite.dash_style,
    'tpmm' : StdSuites.Type_Names_Suite.pixel_map_record,
    'exte' : StdSuites.Type_Names_Suite.extended_real,
    'lrct' : StdSuites.Type_Names_Suite.long_rectangle,
    'prcs' : process,
    'pcap' : application_process,
    'pcda' : desk_accessory_process,
    'capp' : application,
    'ctrs' : trash_2d_object,
    'cdsk' : desktop_2d_object,
    'ctnr' : container,
    'cfol' : folder,
    'cdis' : disk,
    'capp' : application,
    'alia' : alias_file,
    'pack' : package,
    'file' : file,
    'appf' : application_file,
    'inlf' : internet_location_file,
    'docf' : document_file,
    'clpf' : clipping,
    'pwnd' : preferences_window,
    'brow' : Finder_window,
    'cwin' : window,
    'lwnd' : clipping_window,
    'iwnd' : information_window,
    'cobj' : item,
    'icop' : icon_view_options,
    'cprf' : preferences,
    'alst' : alias_list,
    'ifam' : icon_family,
    'clbl' : label,
    'lvcl' : column,
    'lvop' : list_view_options,
}


class Finder(Standard_Suite_Events,
        Legacy_suite_Events,
        Containers_and_folders_Events,
        Files_Events,
        Finder_Basics_Events,
        Finder_items_Events,
        Window_classes_Events,
        Type_Definitions_Events,
        Enumerations_Events,
        aetools.TalkTo):
    _signature = 'MACS'

    _moduleName = 'Finder'

    _elemdict = application._elemdict
    _propdict = application._propdict
